/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_fiG6y534);
  numBytes += sLine_init(&sLine_VeXpze6x);
  numBytes += sLine_init(&sLine_TneaQYOq);
  numBytes += sLine_init(&sLine_uEJZMqII);
  numBytes += sLine_init(&sLine_1iDVnS2g);
  numBytes += sBiquad_init(&sBiquad_s_XS0XcdT2);
  numBytes += sLine_init(&sLine_tY2hs6cy);
  numBytes += sLine_init(&sLine_o63Ff4rH);
  numBytes += sLine_init(&sLine_0bMiTH4r);
  numBytes += sLine_init(&sLine_QqDNPqmM);
  numBytes += sBiquad_init(&sBiquad_s_S8QGwJDU);
  numBytes += sLine_init(&sLine_L9L6MGll);
  numBytes += sLine_init(&sLine_4MIpeaae);
  numBytes += sLine_init(&sLine_0Tt9SfHv);
  numBytes += sLine_init(&sLine_ieujRx1x);
  numBytes += sLine_init(&sLine_bdGJMOx3);
  numBytes += sBiquad_init(&sBiquad_s_KU5b9IXy);
  numBytes += sLine_init(&sLine_kWVUI3At);
  numBytes += sLine_init(&sLine_knp1B6Mm);
  numBytes += sLine_init(&sLine_0u8X6y57);
  numBytes += sLine_init(&sLine_QiGryqOZ);
  numBytes += sLine_init(&sLine_WAZh7KMl);
  numBytes += sBiquad_init(&sBiquad_s_lBNKBqYC);
  numBytes += sLine_init(&sLine_tFHfeXVs);
  numBytes += sLine_init(&sLine_AHdHCt7F);
  numBytes += sLine_init(&sLine_o18T6DQj);
  numBytes += sLine_init(&sLine_BMz4b187);
  numBytes += sBiquad_init(&sBiquad_s_TB2Tq8cg);
  numBytes += sLine_init(&sLine_TJ9u0lih);
  numBytes += sLine_init(&sLine_lFqLiJIY);
  numBytes += sLine_init(&sLine_jq40YfLY);
  numBytes += sLine_init(&sLine_vwhRcaVJ);
  numBytes += sLine_init(&sLine_e8kOgwOL);
  numBytes += sBiquad_init(&sBiquad_s_05B3FoOo);
  numBytes += sLine_init(&sLine_o9Dz2yYV);
  numBytes += sTabread_init(&sTabread_nScVQPQn, &hTable_R2myzqZT, true);
  numBytes += sLine_init(&sLine_pNpGbAU1);
  numBytes += sLine_init(&sLine_HVHhQz9Q);
  numBytes += sTabread_init(&sTabread_uLLhEZG3, &hTable_MVN5OxWD, true);
  numBytes += sLine_init(&sLine_1ArEpuaH);
  numBytes += sRPole_init(&sRPole_2Mar3zLy);
  numBytes += sDel1_init(&sDel1_t7V2TcWb);
  numBytes += sTabwrite_init(&sTabwrite_k20G8px1, &hTable_R2myzqZT);
  numBytes += sRPole_init(&sRPole_bHkv0CvB);
  numBytes += sDel1_init(&sDel1_dEYxticl);
  numBytes += sTabwrite_init(&sTabwrite_6Uvf39V7, &hTable_MVN5OxWD);
  numBytes += sLine_init(&sLine_JZmg7oYm);
  numBytes += sLine_init(&sLine_fEhizGBK);
  numBytes += sRPole_init(&sRPole_Hu85Om2N);
  numBytes += sEnv_init(&sEnv_oaWibKmX, 1024, 512);
  numBytes += sRPole_init(&sRPole_vRIlVije);
  numBytes += sLine_init(&sLine_a5T0cMIQ);
  numBytes += sLine_init(&sLine_4koZv0G8);
  numBytes += sRPole_init(&sRPole_q5JBPriZ);
  numBytes += sEnv_init(&sEnv_4aE44HEO, 1024, 512);
  numBytes += sRPole_init(&sRPole_keNIYp3d);
  numBytes += sLine_init(&sLine_JxiuCwrU);
  numBytes += sTabread_init(&sTabread_w1wb83pu, &hTable_oRRCkbeO, true);
  numBytes += sLine_init(&sLine_kDSOVsqg);
  numBytes += sLine_init(&sLine_lPVZE2Vi);
  numBytes += sTabread_init(&sTabread_Bo9vkCmw, &hTable_xSB6bK9e, true);
  numBytes += sLine_init(&sLine_QfzYVHoh);
  numBytes += sRPole_init(&sRPole_L7WpME91);
  numBytes += sDel1_init(&sDel1_5pNwaHjF);
  numBytes += sTabwrite_init(&sTabwrite_RNIJIcwq, &hTable_oRRCkbeO);
  numBytes += sRPole_init(&sRPole_E5kuV6EJ);
  numBytes += sDel1_init(&sDel1_mME5u3Er);
  numBytes += sTabwrite_init(&sTabwrite_4Dv0Py1I, &hTable_xSB6bK9e);
  numBytes += sLine_init(&sLine_y8EwRDFa);
  numBytes += sLine_init(&sLine_p1YAPTc4);
  numBytes += sRPole_init(&sRPole_DDQlKfNe);
  numBytes += sEnv_init(&sEnv_FcFpgtGw, 1024, 512);
  numBytes += sRPole_init(&sRPole_3XujMGD0);
  numBytes += sLine_init(&sLine_AaYX8chq);
  numBytes += sLine_init(&sLine_z5IGU0Mz);
  numBytes += sRPole_init(&sRPole_IAoRAWuU);
  numBytes += sEnv_init(&sEnv_5PJyj5U6, 1024, 512);
  numBytes += sRPole_init(&sRPole_wH7rsJHc);
  numBytes += sLine_init(&sLine_CsWu34YR);
  numBytes += sTabread_init(&sTabread_LeONmoMc, &hTable_kM4T4Iep, true);
  numBytes += sLine_init(&sLine_GtPd1Ei0);
  numBytes += sLine_init(&sLine_BH6kGA86);
  numBytes += sTabread_init(&sTabread_gGnZJsO8, &hTable_He6s9FFS, true);
  numBytes += sLine_init(&sLine_iJTp0Xx5);
  numBytes += sRPole_init(&sRPole_XlzwbeIP);
  numBytes += sDel1_init(&sDel1_l4XI1Fmf);
  numBytes += sTabwrite_init(&sTabwrite_NfuZeXac, &hTable_kM4T4Iep);
  numBytes += sRPole_init(&sRPole_yiRWdndy);
  numBytes += sDel1_init(&sDel1_Hcb8OVwu);
  numBytes += sTabwrite_init(&sTabwrite_i9jtsZhG, &hTable_He6s9FFS);
  numBytes += sLine_init(&sLine_0qYUVJxN);
  numBytes += sLine_init(&sLine_Zm9kYflH);
  numBytes += sRPole_init(&sRPole_Pbg0Kjnx);
  numBytes += sEnv_init(&sEnv_juL7aCDs, 1024, 512);
  numBytes += sRPole_init(&sRPole_JBfpVrPp);
  numBytes += sLine_init(&sLine_y5OOJdrK);
  numBytes += sLine_init(&sLine_5S8dJErk);
  numBytes += sRPole_init(&sRPole_61dG7IOa);
  numBytes += sEnv_init(&sEnv_DkRqr3xX, 1024, 512);
  numBytes += sRPole_init(&sRPole_jzFpBvFF);
  numBytes += cVar_init_f(&cVar_RjW0suIO, 0.0f);
  numBytes += cVar_init_f(&cVar_G0uDoKEJ, 0.0f);
  numBytes += cVar_init_f(&cVar_y8smK4aw, 0.0f);
  numBytes += cVar_init_f(&cVar_YDcjCjga, 0.0f);
  numBytes += cSlice_init(&cSlice_MTd71HE7, 1, -1);
  numBytes += cVar_init_f(&cVar_8gw4BkbR, 1337.0f);
  numBytes += cVar_init_f(&cVar_5LmQIXF1, 0.0f);
  numBytes += cIf_init(&cIf_37xXpuz4, false);
  numBytes += cIf_init(&cIf_CW7Y0cau, false);
  numBytes += cBinop_init(&cBinop_WgNGN1u4, 0.0f); // __pow
  numBytes += cIf_init(&cIf_PwoUaMOY, false);
  numBytes += cBinop_init(&cBinop_Rl1i6rSa, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_woLdD3Is, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_RJUVDjrX, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_e6gbqMd2, 0.0f);
  numBytes += cIf_init(&cIf_RpOH7nBF, false);
  numBytes += cIf_init(&cIf_M0hDe53A, false);
  numBytes += cBinop_init(&cBinop_74RICzMl, 0.0f); // __pow
  numBytes += cIf_init(&cIf_pCiNhpbv, false);
  numBytes += cBinop_init(&cBinop_uh6agAYY, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Qj3GSEkk, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_rxrlNWRe, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Jqq0QgVR, 0.0f);
  numBytes += cIf_init(&cIf_ekr1ZdHs, false);
  numBytes += cIf_init(&cIf_eEdl1EDe, false);
  numBytes += cBinop_init(&cBinop_npID4OP2, 0.0f); // __pow
  numBytes += cIf_init(&cIf_FemKF9mG, false);
  numBytes += cBinop_init(&cBinop_MIPklOZ7, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ZPtTkoa2, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_32v58uQH, -15.0f); // __eq
  numBytes += cIf_init(&cIf_NUpNkzhR, false);
  numBytes += cSlice_init(&cSlice_GSbAGKQE, 1, -1);
  numBytes += cVar_init_f(&cVar_A3NKbzaV, 0.0f);
  numBytes += cSlice_init(&cSlice_3u0Ihia5, 1, -1);
  numBytes += cVar_init_f(&cVar_thM8cOWw, 0.0f);
  numBytes += cSlice_init(&cSlice_bjvqk8dL, 1, -1);
  numBytes += cVar_init_f(&cVar_t1NnIfOE, 0.0f);
  numBytes += cSlice_init(&cSlice_MwtRDMOf, 1, -1);
  numBytes += cVar_init_f(&cVar_oRY7RWtK, 0.313f);
  numBytes += cBinop_init(&cBinop_eJaGG6xA, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_mjTtrITk, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_CidxG72Q, 0.0f);
  numBytes += cVar_init_f(&cVar_WcFmTRzH, 1337.0f);
  numBytes += cVar_init_f(&cVar_5keNDb4W, 0.3f);
  numBytes += cBinop_init(&cBinop_pr4piZYu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KEvL6AI1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_f5ZYyxNh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zfy1V5ea, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ROosWSFM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nWEstREx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_D3yI5dg6, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_VmalYBgO, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_He8Z2LUb, 0.0f);
  numBytes += cVar_init_f(&cVar_4U2CEBc0, 1337.0f);
  numBytes += cVar_init_f(&cVar_is1wPutt, 0.313f);
  numBytes += cBinop_init(&cBinop_JGQOakqJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_E74i8dXw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_J7Ov8ZY8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4onO9ZV6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lR8r7Rxj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MqNXXZHO, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_JxbDdiBG, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ikSuZH5B, 0.0f);
  numBytes += cVar_init_f(&cVar_JDDkkKAM, 1037.0f);
  numBytes += cVar_init_f(&cVar_e1aPxGuu, 0.4f);
  numBytes += cBinop_init(&cBinop_5L3LLGTN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_neK5d9nG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LmlKVLkJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GCH4LlHZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XYbmswpR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3SQ0AoFI, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_51mKTE7M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yKp4x5iN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XKEKwLNW, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_8brvIaxv, 1, -1);
  numBytes += cVar_init_f(&cVar_OFoAAuRR, 1337.0f);
  numBytes += cVar_init_f(&cVar_Rz1A6I2m, 0.0f);
  numBytes += cIf_init(&cIf_2pX77CbU, false);
  numBytes += cIf_init(&cIf_SMZZscix, false);
  numBytes += cBinop_init(&cBinop_Bfg4eiky, 0.0f); // __pow
  numBytes += cIf_init(&cIf_5QzQk5f0, false);
  numBytes += cBinop_init(&cBinop_44XgG9uf, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_aWYsItyI, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_JCU5I2x4, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_bb6fFvzH, 0.0f);
  numBytes += cIf_init(&cIf_a3UwhUoc, false);
  numBytes += cIf_init(&cIf_eSKDtoWW, false);
  numBytes += cBinop_init(&cBinop_nvsWvVVq, 0.0f); // __pow
  numBytes += cIf_init(&cIf_KYIQXFdl, false);
  numBytes += cBinop_init(&cBinop_lFxnFYWM, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_qPStWYkH, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_UpVdTE3l, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_B73uDL98, 0.0f);
  numBytes += cIf_init(&cIf_aFUUN4rb, false);
  numBytes += cIf_init(&cIf_7bXkWRSZ, false);
  numBytes += cBinop_init(&cBinop_Qzg7un4d, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Husmx9Fw, false);
  numBytes += cBinop_init(&cBinop_7PyRzMal, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_c5mJVTe1, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_CpYe2XWB, -15.0f); // __eq
  numBytes += cIf_init(&cIf_cgeZWFgL, false);
  numBytes += cSlice_init(&cSlice_dHfkF8qh, 1, -1);
  numBytes += cVar_init_f(&cVar_73Ii4imu, 0.0f);
  numBytes += cSlice_init(&cSlice_yJrfCZP2, 1, -1);
  numBytes += cVar_init_f(&cVar_8vn2Bogi, 0.0f);
  numBytes += cSlice_init(&cSlice_DE1N7xmL, 1, -1);
  numBytes += cVar_init_f(&cVar_o5rak8md, 0.0f);
  numBytes += cSlice_init(&cSlice_dq5w1ZlS, 1, -1);
  numBytes += cVar_init_f(&cVar_F7gg1vEQ, 0.313f);
  numBytes += cBinop_init(&cBinop_4TIJvFCC, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_dlhtLeqm, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_hnjsuZLN, 0.0f);
  numBytes += cVar_init_f(&cVar_vTt8KSLM, 1337.0f);
  numBytes += cVar_init_f(&cVar_7CX1zIBb, 0.3f);
  numBytes += cBinop_init(&cBinop_ofgzU0JO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WjPOiiA9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lGQKZ1jA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AZytIZGF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KsxG9SYV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tWikztg5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1ERSQsFq, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Gpf6vW0s, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_kqcgLEp9, 0.0f);
  numBytes += cVar_init_f(&cVar_2I9BCIBI, 1337.0f);
  numBytes += cVar_init_f(&cVar_W5hqsqwl, 0.313f);
  numBytes += cBinop_init(&cBinop_f4Fr2OKf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Vz5U03nt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DKmt8Zu1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OD8r4vgK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_y79wc6To, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KQLFixbZ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_wMRsLuxL, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_QoIniWQA, 0.0f);
  numBytes += cVar_init_f(&cVar_LIZZliT5, 1037.0f);
  numBytes += cVar_init_f(&cVar_DLDkfuUQ, 0.4f);
  numBytes += cBinop_init(&cBinop_dVNenUoN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_r8fCjQ91, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IlV4tADR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UvePjrpV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PrbUMSXD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ao7Z5BLZ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_r6SS0Hq9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4uGd7y62, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bwd5ZXj7, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_HyLeMuXe, 5705.6f);
  numBytes += cVar_init_f(&cVar_2Y7qSF9z, 313.3f);
  numBytes += cBinop_init(&cBinop_ppdR7a82, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_pCni0f4L, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_LW3Eon4H, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_QdqnjVzh, 0.0f);
  numBytes += cVar_init_f(&cVar_Zxhom8ia, 0.0f);
  numBytes += cVar_init_f(&cVar_E0yR0UYD, 0.0f);
  numBytes += cVar_init_f(&cVar_FpZMV20F, 0.0f);
  numBytes += cVar_init_f(&cVar_2ompYh3R, 0.0f);
  numBytes += cVar_init_f(&cVar_Cu1Xbmzw, 0.0f);
  numBytes += cVar_init_f(&cVar_phbtKwej, 0.0f);
  numBytes += cVar_init_f(&cVar_QH7HWYr7, 0.0f);
  numBytes += cVar_init_f(&cVar_34lAlugV, 0.0f);
  numBytes += cVar_init_f(&cVar_hzFGP4oM, 0.0f);
  numBytes += cVar_init_f(&cVar_IdviiyFi, 0.0f);
  numBytes += cVar_init_f(&cVar_POFNbRDe, 0.0f);
  numBytes += cSlice_init(&cSlice_WbzS6g4B, 1, -1);
  numBytes += cVar_init_f(&cVar_dk4mW59N, 0.5f);
  numBytes += cSlice_init(&cSlice_wg1ShnRF, 1, -1);
  numBytes += cVar_init_f(&cVar_xatP3RCq, 0.2f);
  numBytes += cSlice_init(&cSlice_0dpDVWH3, 1, -1);
  numBytes += cVar_init_f(&cVar_cdRXixPY, 500.0f);
  numBytes += sVarf_init(&sVarf_VWITC6TO, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_1LGNMZaK, 600.0f);
  numBytes += cBinop_init(&cBinop_tKUUKoW7, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_PiVErwoQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oI3sGbOq, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_1KrFFXYf, 600.0f);
  numBytes += cBinop_init(&cBinop_j61qRklR, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_cOU2HYTP, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_vFu3fWZ9, 4000.0f);
  numBytes += cBinop_init(&cBinop_YVx3IsvZ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_GbaiSpKi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hLI7WdGP, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_vgLyB0Jv, 4000.0f);
  numBytes += cBinop_init(&cBinop_OuGPLPDD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_lWEnBNlj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dNS4hUBP, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_nlL1nfYc, false);
  numBytes += cBinop_init(&cBinop_rG7T6img, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_n95b7N4O, 20.0f);
  numBytes += cBinop_init(&cBinop_ftQeJuGX, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_p9M7SlsG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_suDzppjU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_10ybToXQ, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_pp1cY2op, false);
  numBytes += cBinop_init(&cBinop_ez9RsvIl, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_F6IbCUHM, 20.0f);
  numBytes += cBinop_init(&cBinop_zgIYExkM, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_78Em2qIu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Rlnd8Glw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EZLhgpN1, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_11deG3Yi, 1, -1);
  numBytes += cVar_init_f(&cVar_YID1maYG, 0.25f);
  numBytes += cDelay_init(this, &cDelay_94cCukWY, 0.0f);
  numBytes += cDelay_init(this, &cDelay_99baWNao, 0.0f);
  numBytes += hTable_init(&hTable_R2myzqZT, 256);
  numBytes += cTabhead_init(&cTabhead_yLqi2VcO, &hTable_R2myzqZT);
  numBytes += cVar_init_s(&cVar_bqVNDKqs, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_8aEDAqxR, 0.0f);
  numBytes += cDelay_init(this, &cDelay_tvc2r84H, 0.0f);
  numBytes += cBinop_init(&cBinop_3z0xfpc4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1gnGzsH7, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_cjh2OyRl, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_eaWFgQaJ, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_3M9qj4k0, 0.0f);
  numBytes += cDelay_init(this, &cDelay_RLEjMWly, 0.0f);
  numBytes += hTable_init(&hTable_MVN5OxWD, 256);
  numBytes += cTabhead_init(&cTabhead_Sv1dHVn2, &hTable_MVN5OxWD);
  numBytes += cVar_init_s(&cVar_cdjOYsEb, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_3IYGAz9X, 0.0f);
  numBytes += cDelay_init(this, &cDelay_VkCWtASq, 0.0f);
  numBytes += cBinop_init(&cBinop_1pDXcWFs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KNPiKHer, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_nOFdmC8o, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_9twMdQVd, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_NPfHHC5z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FZH55G9l, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e6yP8oMb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7RyaHMyZ, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_qb9NTO4R, 1, -1);
  numBytes += cVar_init_f(&cVar_YCPPa911, 0.5f);
  numBytes += cSlice_init(&cSlice_GHRhSJms, 1, -1);
  numBytes += cVar_init_f(&cVar_ylhZHTDa, 0.2f);
  numBytes += cSlice_init(&cSlice_22UejtaT, 1, -1);
  numBytes += cVar_init_f(&cVar_EeAq0RHQ, 500.0f);
  numBytes += sVarf_init(&sVarf_DRI09thR, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_b46s5Yuc, 600.0f);
  numBytes += cBinop_init(&cBinop_3PF1kap8, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Z395AaB4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_g7xs0Tez, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_1Z9OjhG3, 600.0f);
  numBytes += cBinop_init(&cBinop_gRUsvGgT, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_3JhCjtfZ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Svqn8Egk, 4000.0f);
  numBytes += cBinop_init(&cBinop_O3IzRepb, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_a10UnPnL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oAMUG4M4, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_sY0VLE3M, 4000.0f);
  numBytes += cBinop_init(&cBinop_TvE7QNEo, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_TK8LsR9Y, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ssS4xncX, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_XxZZzshE, false);
  numBytes += cBinop_init(&cBinop_20crV7nd, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_nEOAieb9, 20.0f);
  numBytes += cBinop_init(&cBinop_IhtztkKD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_evXbVldn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eRo1Njsy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tiXGAA9w, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_uwfka12b, false);
  numBytes += cBinop_init(&cBinop_ByfWtqPs, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_Q0M8aSZe, 20.0f);
  numBytes += cBinop_init(&cBinop_czS5iKmS, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_zotlnyDh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QlJzKQEs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BQcCus2N, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_fN4lkOKs, 1, -1);
  numBytes += cVar_init_f(&cVar_ouQtAJ3I, 0.25f);
  numBytes += cDelay_init(this, &cDelay_8iFHO9ju, 0.0f);
  numBytes += cDelay_init(this, &cDelay_mebqFCd9, 0.0f);
  numBytes += hTable_init(&hTable_oRRCkbeO, 256);
  numBytes += cTabhead_init(&cTabhead_njs6DGCA, &hTable_oRRCkbeO);
  numBytes += cVar_init_s(&cVar_gsih3KVF, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_cNMXAuxb, 0.0f);
  numBytes += cDelay_init(this, &cDelay_vzZSrqoy, 0.0f);
  numBytes += cBinop_init(&cBinop_9jUjqXDS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9jBDlUKf, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_U81hpKiu, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_GLsEE6HF, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_F0cDWDsR, 0.0f);
  numBytes += cDelay_init(this, &cDelay_26BWTfH5, 0.0f);
  numBytes += hTable_init(&hTable_xSB6bK9e, 256);
  numBytes += cTabhead_init(&cTabhead_RbjVJ54y, &hTable_xSB6bK9e);
  numBytes += cVar_init_s(&cVar_kuVIzDlx, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_nxofu98h, 0.0f);
  numBytes += cDelay_init(this, &cDelay_LPw2tMeX, 0.0f);
  numBytes += cBinop_init(&cBinop_UwSsbLVV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_byzmLiAt, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_OYluVjm3, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_IZx2i5Su, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_ysubGMOm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_62APFNfR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Bbk0irTW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LuraM9ou, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_MBY5WCXS, 1, -1);
  numBytes += cVar_init_f(&cVar_SllWV9Ve, 0.5f);
  numBytes += cSlice_init(&cSlice_FJJTm7s2, 1, -1);
  numBytes += cVar_init_f(&cVar_ovezZS1h, 0.2f);
  numBytes += cSlice_init(&cSlice_QbyN00Qf, 1, -1);
  numBytes += cVar_init_f(&cVar_nnyyOWry, 500.0f);
  numBytes += sVarf_init(&sVarf_57agI3uY, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_oKEGWkLK, 600.0f);
  numBytes += cBinop_init(&cBinop_RcTTZBVe, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_0rf5BjXd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9YBWklWT, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_v0wvXDMn, 600.0f);
  numBytes += cBinop_init(&cBinop_Zu4XGwcD, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_sywZ3S7M, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_aC4wXbIZ, 4000.0f);
  numBytes += cBinop_init(&cBinop_Umas2s8y, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_hhgkU99N, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dMYRclrw, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_6gzWtZjj, 4000.0f);
  numBytes += cBinop_init(&cBinop_baJkrYtZ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_sK1IrKlT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BWaM5VKC, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_YkIfry0b, false);
  numBytes += cBinop_init(&cBinop_6c9EuX1w, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_F9m0rpZg, 20.0f);
  numBytes += cBinop_init(&cBinop_YWr38sL6, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_HbIulFDV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FaTgmkQJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Xent26Vk, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_M1L36Djn, false);
  numBytes += cBinop_init(&cBinop_GYlvlBCy, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_tftUM1ZI, 20.0f);
  numBytes += cBinop_init(&cBinop_vBlO2N9J, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Qbg2q7g1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nq66zUOl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GOBbsio9, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_gZDt0Lxn, 1, -1);
  numBytes += cVar_init_f(&cVar_zW7szdpD, 0.25f);
  numBytes += cDelay_init(this, &cDelay_mvTUFyS4, 0.0f);
  numBytes += cDelay_init(this, &cDelay_04vf9zV7, 0.0f);
  numBytes += hTable_init(&hTable_kM4T4Iep, 256);
  numBytes += cTabhead_init(&cTabhead_1mIa3Y8v, &hTable_kM4T4Iep);
  numBytes += cVar_init_s(&cVar_2W8wEOre, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_NmPSMefJ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_pU6uA26j, 0.0f);
  numBytes += cBinop_init(&cBinop_i9XznoTl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3hlGoZ85, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_DK3YmITt, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_lbTnbFu7, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_vB4pS315, 0.0f);
  numBytes += cDelay_init(this, &cDelay_skXfkBkk, 0.0f);
  numBytes += hTable_init(&hTable_He6s9FFS, 256);
  numBytes += cTabhead_init(&cTabhead_5Pd8p5ZE, &hTable_He6s9FFS);
  numBytes += cVar_init_s(&cVar_llwV4VcY, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_UpJi5cso, 0.0f);
  numBytes += cDelay_init(this, &cDelay_W4GGN6XC, 0.0f);
  numBytes += cBinop_init(&cBinop_BnYvU5H1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9RFLRsAr, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_pmh7Pgyu, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_9hhVHGbC, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_o6RKprAI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OhKUwzvs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hUu53iti, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hUI6Sexy, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_jFrr6FEN, 1.0f);
  numBytes += cIf_init(&cIf_5YsdFUXb, false);
  numBytes += cIf_init(&cIf_egspMgUD, false);
  numBytes += cVar_init_f(&cVar_ZViYPiP6, 0.0f);
  numBytes += cVar_init_f(&cVar_oeMlSTCh, 0.0f);
  numBytes += cVar_init_f(&cVar_zYYqHFC6, 1.0f);
  numBytes += cIf_init(&cIf_h6bc3OLW, false);
  numBytes += cIf_init(&cIf_3fm2wcME, false);
  numBytes += cVar_init_f(&cVar_QLkj3W6a, 0.0f);
  numBytes += cVar_init_f(&cVar_Da6UDJos, 0.0f);
  numBytes += cVar_init_f(&cVar_xPHm1fXR, 1.0f);
  numBytes += cIf_init(&cIf_1xzRAbNo, false);
  numBytes += cIf_init(&cIf_ecEnxNYM, false);
  numBytes += cVar_init_f(&cVar_I30FAzAH, 0.0f);
  numBytes += cVar_init_f(&cVar_iLSPKDMl, 0.0f);
  numBytes += cVar_init_f(&cVar_Iy1z3EXG, 60000.0f);
  numBytes += cVar_init_f(&cVar_VAccfhpB, 500.0f);
  numBytes += cSlice_init(&cSlice_jgYsmRpo, 1, -1);
  numBytes += cSlice_init(&cSlice_uIYwQHzv, 1, -1);
  numBytes += cVar_init_f(&cVar_9XIJ2A1B, 0.0f);
  numBytes += cIf_init(&cIf_Ha837b36, false);
  numBytes += cBinop_init(&cBinop_FSJ0TERl, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_8moU870I, 120.0f);
  numBytes += cBinop_init(&cBinop_C8xhqsvn, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_A07Pbfcg, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_4mp9q3pr, 60000.0f);
  numBytes += cVar_init_f(&cVar_XqJH8Vyy, 500.0f);
  numBytes += cSlice_init(&cSlice_I8M3TgMR, 1, -1);
  numBytes += cSlice_init(&cSlice_FHTmA47I, 1, -1);
  numBytes += cVar_init_f(&cVar_33NPZ0kB, 0.0f);
  numBytes += cIf_init(&cIf_yaTB7AJz, false);
  numBytes += cBinop_init(&cBinop_JlayS1vu, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_E5TC2wnS, 120.0f);
  numBytes += cBinop_init(&cBinop_lKbqvUti, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_BjmrDDFD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ufzRF05v, 60000.0f);
  numBytes += cVar_init_f(&cVar_AC6a8xZ2, 500.0f);
  numBytes += cSlice_init(&cSlice_cSCxawB4, 1, -1);
  numBytes += cSlice_init(&cSlice_ld9YEEz9, 1, -1);
  numBytes += cVar_init_f(&cVar_lLSO4AFQ, 0.0f);
  numBytes += cIf_init(&cIf_6vSAnowe, false);
  numBytes += cBinop_init(&cBinop_PMtv59fc, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_rPEiZk2H, 120.0f);
  numBytes += cBinop_init(&cBinop_qZK2MOwd, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_ghdJl2JB, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_RoE4Cp4Z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e1rmFGbQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qUT5pV1v, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HibrmJ6G, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_18PdKuYo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XLQK7Nbd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eElseLt1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JQsEUnrf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jyeBxbBW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EzaPhrWD, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_oaWibKmX);
  sEnv_free(&sEnv_4aE44HEO);
  sEnv_free(&sEnv_FcFpgtGw);
  sEnv_free(&sEnv_5PJyj5U6);
  sEnv_free(&sEnv_juL7aCDs);
  sEnv_free(&sEnv_DkRqr3xX);
  hTable_free(&hTable_R2myzqZT);
  hTable_free(&hTable_MVN5OxWD);
  hTable_free(&hTable_oRRCkbeO);
  hTable_free(&hTable_xSB6bK9e);
  hTable_free(&hTable_kM4T4Iep);
  hTable_free(&hTable_He6s9FFS);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_R2myzqZT; // del-1349-delayL
    case 0x19A00729: return &hTable_MVN5OxWD; // del-1349-delayR
    case 0x584C8281: return &hTable_oRRCkbeO; // del-1428-delayL
    case 0x54BF59F6: return &hTable_xSB6bK9e; // del-1428-delayR
    case 0xBCE693A: return &hTable_kM4T4Iep; // del-1507-delayL
    case 0x95A380B3: return &hTable_He6s9FFS; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MPW1zVT4_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bQVr6Unj_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tb3HZcz5_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pRULAY6S_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7RTFSgc0_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TGZtYfLt_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YZM4OsHU_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YiAFrJDA_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ts7B3nuo_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JJlHctv2_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_isqyCBK1_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4xtqEXeM_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NHG71IaE_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JUrNpTTX_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_d4L9g3F0_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gV1c3zEZ_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w65Wp7K1_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Uk23L6Ki_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tD9XkNaZ_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ify9ZVpj_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4n0dFnzR_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PaGJ05I9_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S2A7ZvXV_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kZknpgBu_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NlZYKUy9_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GCkY0jog_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gogYyWze_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ACVPVQ4e_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kxm5lUrS_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zOqlYOFY_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lk9jW1hb_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Yd23yfli_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mY2w3VIk_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pWBoqbiY_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AwfKSAnL_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uBbzPtti_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CtLb9Rd0_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fFbwT78p_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nwGKluU9_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mYCQIPa8_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qSwnDbdr_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t85YnDAL_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7cmKEYq8_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cq5WSo2z_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BfYkTX4c_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hoxivpse_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xhS63ChB_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bgJ9zFsx_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t0H4BWas_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p24hq75h_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mDf5IzQx_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5EQ5ZztI_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BLQqcCdf_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_g0DOKFfh_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4CUFSKln_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_39k99Faq_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KTgqqOYO_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0wiig83b_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uzVgDRo0_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3AJScKrz_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jylxf14t_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Pg9YN0bO_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m3BlYXAJ_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_itNsLg7G_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_RjW0suIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RSU5xwLM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_G0uDoKEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xHr2hw93_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_y8smK4aw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DEnPPMGD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_YDcjCjga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ypCOsAgV_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9IImWtG3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s7gu9ed0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xUksGLGs_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_RvmjBy6c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MTd71HE7, 0, m, &cSlice_MTd71HE7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qdyTADjW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_MTd71HE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_i290uLSl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_i290uLSl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_8gw4BkbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_i290uLSl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_i290uLSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NlZYKUy9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_5LmQIXF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RCsboR9W_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_37xXpuz4, 0, m, &cIf_37xXpuz4_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_37xXpuz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SPrrs2p7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_CW7Y0cau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_n5m6pj7I_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NBPV9nF6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_5wW1klgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WgNGN1u4, HV_BINOP_POW, 0, m, &cBinop_WgNGN1u4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WgNGN1u4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PwoUaMOY, 0, m, &cIf_PwoUaMOY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dvXI72p7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_CXw9PibK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ema9YOaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CW7Y0cau, 0, m, &cIf_CW7Y0cau_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HMXreSFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HIFDOvTy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HIFDOvTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CW7Y0cau, 1, m, &cIf_CW7Y0cau_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NBPV9nF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_dvXI72p7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_n5m6pj7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_PwoUaMOY, 0, m, &cIf_PwoUaMOY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CXw9PibK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WgNGN1u4, HV_BINOP_POW, 1, m, &cBinop_WgNGN1u4_sendMessage);
  cMsg_5wW1klgl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_PwoUaMOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_51mKTE7M, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_RCsboR9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_37xXpuz4, 1, m, &cIf_37xXpuz4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SPrrs2p7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_woLdD3Is, HV_BINOP_GREATER_THAN, 1, m, &cBinop_woLdD3Is_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RJUVDjrX, HV_BINOP_EQ, 1, m, &cBinop_RJUVDjrX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_h0Wr6zBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rl1i6rSa, HV_BINOP_ADD, 0, m, &cBinop_Rl1i6rSa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Rl1i6rSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HMXreSFm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ema9YOaK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_woLdD3Is_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PwoUaMOY, 1, m, &cIf_PwoUaMOY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RJUVDjrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_evrDUh7w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_evrDUh7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_51mKTE7M, m);
}

void Heavy_WSTD_DL3Y::cCast_Z416TJEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rl1i6rSa, HV_BINOP_ADD, 1, m, &cBinop_Rl1i6rSa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_woLdD3Is, HV_BINOP_GREATER_THAN, 0, m, &cBinop_woLdD3Is_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RJUVDjrX, HV_BINOP_EQ, 0, m, &cBinop_RJUVDjrX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3Foh1n2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5LmQIXF1, 0, m, &cVar_5LmQIXF1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SKOOuj3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h0Wr6zBs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_e6gbqMd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nIcfpW1y_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_RpOH7nBF, 0, m, &cIf_RpOH7nBF_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_RpOH7nBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_tPa1tT7Z_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_M0hDe53A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_YMjlaVc6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_xI7Y5n44_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_pObBQceM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_74RICzMl, HV_BINOP_POW, 0, m, &cBinop_74RICzMl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_74RICzMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pCiNhpbv, 0, m, &cIf_pCiNhpbv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AwS4YMIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_om2NT5bF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XmaiDNnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_aZqqw6Yv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KyFccrHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M0hDe53A, 0, m, &cIf_M0hDe53A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aZqqw6Yv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M0hDe53A, 1, m, &cIf_M0hDe53A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xI7Y5n44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_AwS4YMIT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YMjlaVc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_pCiNhpbv, 0, m, &cIf_pCiNhpbv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_om2NT5bF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_74RICzMl, HV_BINOP_POW, 1, m, &cBinop_74RICzMl_sendMessage);
  cMsg_pObBQceM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_pCiNhpbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_u3meVRIq_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VZJmKUjV_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_cyrlZlhw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_nIcfpW1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RpOH7nBF, 1, m, &cIf_RpOH7nBF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tPa1tT7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qj3GSEkk, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Qj3GSEkk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rxrlNWRe, HV_BINOP_EQ, 1, m, &cBinop_rxrlNWRe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qsg0aPsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uh6agAYY, HV_BINOP_ADD, 0, m, &cBinop_uh6agAYY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uh6agAYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XmaiDNnb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KyFccrHH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qj3GSEkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pCiNhpbv, 1, m, &cIf_pCiNhpbv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rxrlNWRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vxlRkb4P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_vxlRkb4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_u3meVRIq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VZJmKUjV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_cyrlZlhw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_apLrbgSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e6gbqMd2, 0, m, &cVar_e6gbqMd2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BJw0DmIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qsg0aPsv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_dkk5H4ax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uh6agAYY, HV_BINOP_ADD, 1, m, &cBinop_uh6agAYY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qj3GSEkk, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Qj3GSEkk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rxrlNWRe, HV_BINOP_EQ, 0, m, &cBinop_rxrlNWRe_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Jqq0QgVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JAp8Va2A_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ekr1ZdHs, 0, m, &cIf_ekr1ZdHs_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ekr1ZdHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Thp4iLUu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_eEdl1EDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_MjzucxWA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_0u0w2rfc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_y6jwfRTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_npID4OP2, HV_BINOP_POW, 0, m, &cBinop_npID4OP2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_npID4OP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FemKF9mG, 0, m, &cIf_FemKF9mG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cutYGaxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_nwsh2riy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zNB5Zf6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GX0quP4l_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zVQrZ62L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eEdl1EDe, 0, m, &cIf_eEdl1EDe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GX0quP4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eEdl1EDe, 1, m, &cIf_eEdl1EDe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0u0w2rfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_cutYGaxR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MjzucxWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_FemKF9mG, 0, m, &cIf_FemKF9mG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nwsh2riy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_npID4OP2, HV_BINOP_POW, 1, m, &cBinop_npID4OP2_sendMessage);
  cMsg_y6jwfRTa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_FemKF9mG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_XKEKwLNW, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_JAp8Va2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ekr1ZdHs, 1, m, &cIf_ekr1ZdHs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Thp4iLUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZPtTkoa2, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ZPtTkoa2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_32v58uQH, HV_BINOP_EQ, 1, m, &cBinop_32v58uQH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iDGc80rV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MIPklOZ7, HV_BINOP_ADD, 0, m, &cBinop_MIPklOZ7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MIPklOZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zNB5Zf6j_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zVQrZ62L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZPtTkoa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FemKF9mG, 1, m, &cIf_FemKF9mG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_32v58uQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sKrlLWzt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_sKrlLWzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XKEKwLNW, m);
}

void Heavy_WSTD_DL3Y::cCast_o3RGIfOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jqq0QgVR, 0, m, &cVar_Jqq0QgVR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QiyTeJn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iDGc80rV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_CyKH0Z5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MIPklOZ7, HV_BINOP_ADD, 1, m, &cBinop_MIPklOZ7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZPtTkoa2, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ZPtTkoa2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_32v58uQH, HV_BINOP_EQ, 0, m, &cBinop_32v58uQH_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_NUpNkzhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_yKp4x5iN, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_XZmagjIq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GSbAGKQE, 0, m, &cSlice_GSbAGKQE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Iff8jv9l_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_GSbAGKQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JtTBoNZp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JtTBoNZp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_A3NKbzaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JtTBoNZp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_JtTBoNZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_S2A7ZvXV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Iff8jv9l_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3u0Ihia5, 0, m, &cSlice_3u0Ihia5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_RvmjBy6c_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_3u0Ihia5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kWmXasDA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kWmXasDA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_thM8cOWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kWmXasDA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_kWmXasDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gogYyWze_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_qdyTADjW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bjvqk8dL, 0, m, &cSlice_bjvqk8dL_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JmetCqub_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_bjvqk8dL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Jj1juSmm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Jj1juSmm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_t1NnIfOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Jj1juSmm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Jj1juSmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kZknpgBu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_JmetCqub_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MwtRDMOf, 0, m, &cSlice_MwtRDMOf_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_MwtRDMOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_i6W5cJE9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_i6W5cJE9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_oRY7RWtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_i6W5cJE9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_i6W5cJE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GCkY0jog_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_VOb4U6lJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fiG6y534, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_5q699mA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VeXpze6x, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_QYv0xUvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TneaQYOq, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JjBwrI0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uEJZMqII, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_r2IqKcE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1iDVnS2g, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6SvejpzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MeZLM1cR_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_MeZLM1cR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eJaGG6xA, HV_BINOP_DIVIDE, 1, m, &cBinop_eJaGG6xA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iRoRjd06_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_aQYKApwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_u2XM7gBx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bKViYlfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_aQYKApwo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u2XM7gBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eJaGG6xA, HV_BINOP_DIVIDE, 0, m, &cBinop_eJaGG6xA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iRoRjd06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bKViYlfj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_eJaGG6xA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mjTtrITk, HV_BINOP_MULTIPLY, 1, m, &cBinop_mjTtrITk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mjTtrITk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RP0nrAX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tyXx0Xlj_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_m2oiTePn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mZEslnfX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_IVoNV9yq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fNmsGhVF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_jw9qS1TA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_LiUgb4JS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LiUgb4JS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mjTtrITk, HV_BINOP_MULTIPLY, 0, m, &cBinop_mjTtrITk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PIGVcqG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_EQWcyFeO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EQWcyFeO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mkyEzPcM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UpAX0zk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CidxG72Q, 1, m, &cVar_CidxG72Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_CidxG72Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yuuD0HAK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_q1QLyrzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KEvL6AI1, HV_BINOP_MULTIPLY, 1, m, &cBinop_KEvL6AI1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lh8x0JPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_q1QLyrzA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9mJBKhX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rqwn0YSn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rqwn0YSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f5ZYyxNh, HV_BINOP_MULTIPLY, 1, m, &cBinop_f5ZYyxNh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3wv6wphg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zfy1V5ea, HV_BINOP_MULTIPLY, 1, m, &cBinop_zfy1V5ea_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ojp3O0GF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3wv6wphg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BZea6vNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ROosWSFM, HV_BINOP_MULTIPLY, 1, m, &cBinop_ROosWSFM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_J8SbWwLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MkfIA9uL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MkfIA9uL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nWEstREx, HV_BINOP_MULTIPLY, 1, m, &cBinop_nWEstREx_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_WcFmTRzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nGVrhmkV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_jw9qS1TA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_84fCwGuv_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_5keNDb4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_PIGVcqG6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tyXx0Xlj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_IVoNV9yq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RP0nrAX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_m2oiTePn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_mZEslnfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zOqlYOFY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_fNmsGhVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kxm5lUrS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_n2M1Old2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ACVPVQ4e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_mkyEzPcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_snlUvuxH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_snlUvuxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pr4piZYu, HV_BINOP_MULTIPLY, 1, m, &cBinop_pr4piZYu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pr4piZYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6Kc1Lnfs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6Kc1Lnfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_n2M1Old2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_yuuD0HAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_sN8XNd4j_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sN8XNd4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jdQBkkN4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ed4bS054_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XrwxVhQb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_89ceocPF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DFKRMGHz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OTq58BUE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KEvL6AI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VOb4U6lJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_f5ZYyxNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5q699mA6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zfy1V5ea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QYv0xUvt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ROosWSFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JjBwrI0W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nWEstREx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r2IqKcE6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_HVWvL3Ls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WcFmTRzH, 0, m, &cVar_WcFmTRzH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vQldbf42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5keNDb4W, 1, m, &cVar_5keNDb4W_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DFKRMGHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f5ZYyxNh, HV_BINOP_MULTIPLY, 0, m, &cBinop_f5ZYyxNh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ed4bS054_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nWEstREx, HV_BINOP_MULTIPLY, 0, m, &cBinop_nWEstREx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_89ceocPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zfy1V5ea, HV_BINOP_MULTIPLY, 0, m, &cBinop_zfy1V5ea_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jdQBkkN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_OTq58BUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KEvL6AI1, HV_BINOP_MULTIPLY, 0, m, &cBinop_KEvL6AI1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XrwxVhQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ROosWSFM, HV_BINOP_MULTIPLY, 0, m, &cBinop_ROosWSFM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nGVrhmkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5keNDb4W, 0, m, &cVar_5keNDb4W_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_84fCwGuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CidxG72Q, 0, m, &cVar_CidxG72Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wXpKp8hw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tY2hs6cy, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Kz6gvqDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o63Ff4rH, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_voX8JEfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0bMiTH4r, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nj1nQH8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QqDNPqmM, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_lW69kk1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kuLADQRu_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_kuLADQRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D3yI5dg6, HV_BINOP_DIVIDE, 1, m, &cBinop_D3yI5dg6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ffKYJ5Nc_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_jLtss3YN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_JpreYYNC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XeVUmR3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_jLtss3YN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JpreYYNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D3yI5dg6, HV_BINOP_DIVIDE, 0, m, &cBinop_D3yI5dg6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ffKYJ5Nc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XeVUmR3z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_D3yI5dg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VmalYBgO, HV_BINOP_MULTIPLY, 1, m, &cBinop_VmalYBgO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VmalYBgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rjzKW2xr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DIAM3ESz_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_LlpSqOHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zXrnYEVU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_YPNrj6d8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_S6It1NP9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_v1JDxOaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_9R932zSM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9R932zSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VmalYBgO, HV_BINOP_MULTIPLY, 0, m, &cBinop_VmalYBgO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NOKTt7Fz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_fZ7GqA3L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fZ7GqA3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5QczvMBd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_dk7RAWAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J7Ov8ZY8, HV_BINOP_MULTIPLY, 1, m, &cBinop_J7Ov8ZY8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d2ig83re_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_He8Z2LUb, 1, m, &cVar_He8Z2LUb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_f77dKKl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4onO9ZV6, HV_BINOP_MULTIPLY, 1, m, &cBinop_4onO9ZV6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_K1Ekb9O3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DcdqOPHz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DcdqOPHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lR8r7Rxj, HV_BINOP_MULTIPLY, 1, m, &cBinop_lR8r7Rxj_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_He8Z2LUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1GQotDLu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_4U2CEBc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6qkGNNVv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_v1JDxOaX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ggfReK5f_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_is1wPutt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_NOKTt7Fz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DIAM3ESz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_YPNrj6d8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rjzKW2xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_LlpSqOHz_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_zXrnYEVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mY2w3VIk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_S6It1NP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Yd23yfli_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Ibi9DQU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lk9jW1hb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_5QczvMBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uMfsjQ4a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uMfsjQ4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JGQOakqJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_JGQOakqJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JGQOakqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jptOewPf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jptOewPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ibi9DQU6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_1GQotDLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7iLTgt4Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7iLTgt4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PacLadDd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wAYYTig4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k1sfJV9p_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xuGFe9g4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_E74i8dXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wXpKp8hw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_J7Ov8ZY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kz6gvqDa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4onO9ZV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_voX8JEfz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lR8r7Rxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nj1nQH8m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_dyWFGHI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4U2CEBc0, 0, m, &cVar_4U2CEBc0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dfOJWqA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_is1wPutt, 1, m, &cVar_is1wPutt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ggfReK5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_He8Z2LUb, 0, m, &cVar_He8Z2LUb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6qkGNNVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_is1wPutt, 0, m, &cVar_is1wPutt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wAYYTig4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4onO9ZV6, HV_BINOP_MULTIPLY, 0, m, &cBinop_4onO9ZV6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xuGFe9g4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E74i8dXw, HV_BINOP_MULTIPLY, 0, m, &cBinop_E74i8dXw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PacLadDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lR8r7Rxj, HV_BINOP_MULTIPLY, 0, m, &cBinop_lR8r7Rxj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_k1sfJV9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J7Ov8ZY8, HV_BINOP_MULTIPLY, 0, m, &cBinop_J7Ov8ZY8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7dlVlle9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L9L6MGll, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_kk5gh9FX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4MIpeaae, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_js33TrTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0Tt9SfHv, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_STptGsAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ieujRx1x, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_MVgTJf7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bdGJMOx3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_gtDTVefu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gyIRZNsD_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_gyIRZNsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MqNXXZHO, HV_BINOP_DIVIDE, 1, m, &cBinop_MqNXXZHO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NRWD00RB_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_8xJbADOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_kPfiRfau_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jmqnmaCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_8xJbADOh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kPfiRfau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MqNXXZHO, HV_BINOP_DIVIDE, 0, m, &cBinop_MqNXXZHO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NRWD00RB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jmqnmaCm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_MqNXXZHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JxbDdiBG, HV_BINOP_MULTIPLY, 1, m, &cBinop_JxbDdiBG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JxbDdiBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wR2zm1vI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jqetikls_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_G8gcm895_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wxjgtlbC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_eIsNROR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8U7jmj6n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_koKJCwX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_FSlSyvx4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FSlSyvx4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JxbDdiBG, HV_BINOP_MULTIPLY, 0, m, &cBinop_JxbDdiBG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cEjBncDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_3yOksM3f_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3yOksM3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gHWCeD2J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QaYvmKAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_neK5d9nG, HV_BINOP_MULTIPLY, 1, m, &cBinop_neK5d9nG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Z0D30M4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7EMMItAV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7EMMItAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QaYvmKAg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_erwO3C3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MbjoqkeJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MbjoqkeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LmlKVLkJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_LmlKVLkJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rcISm4Sr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GCH4LlHZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_GCH4LlHZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CxDXypju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZSl4bPcy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZSl4bPcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rcISm4Sr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W52BGA5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ikSuZH5B, 1, m, &cVar_ikSuZH5B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AorZr3GR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XYbmswpR, HV_BINOP_MULTIPLY, 1, m, &cBinop_XYbmswpR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dzNXn0qn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tLYdlg7Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tLYdlg7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3SQ0AoFI, HV_BINOP_MULTIPLY, 1, m, &cBinop_3SQ0AoFI_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ikSuZH5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d6t9i2qa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_JDDkkKAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XygtwCCv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_koKJCwX3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pfEc9bYc_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_e1aPxGuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_cEjBncDg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Jqetikls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_eIsNROR4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wR2zm1vI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_G8gcm895_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_wxjgtlbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uBbzPtti_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_8U7jmj6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AwfKSAnL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_66JWii7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pWBoqbiY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_gHWCeD2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cEesLXGB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cEesLXGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5L3LLGTN, HV_BINOP_MULTIPLY, 1, m, &cBinop_5L3LLGTN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5L3LLGTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rtvnQouq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rtvnQouq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_66JWii7J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_d6t9i2qa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_So3HgcPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_So3HgcPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GiCITUi4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ouGDa2b7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tha4UhpY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dPBgFfr0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v6xhYjwU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aVHj0hgv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_neK5d9nG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7dlVlle9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LmlKVLkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kk5gh9FX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_GCH4LlHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_js33TrTt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XYbmswpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_STptGsAM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3SQ0AoFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MVgTJf7U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_c8NTTpkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JDDkkKAM, 0, m, &cVar_JDDkkKAM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YzpL01nZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e1aPxGuu, 1, m, &cVar_e1aPxGuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aVHj0hgv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_neK5d9nG, HV_BINOP_MULTIPLY, 0, m, &cBinop_neK5d9nG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Tha4UhpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XYbmswpR, HV_BINOP_MULTIPLY, 0, m, &cBinop_XYbmswpR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_v6xhYjwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LmlKVLkJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_LmlKVLkJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ouGDa2b7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3SQ0AoFI, HV_BINOP_MULTIPLY, 0, m, &cBinop_3SQ0AoFI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dPBgFfr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GCH4LlHZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_GCH4LlHZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GiCITUi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_pfEc9bYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ikSuZH5B, 0, m, &cVar_ikSuZH5B_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XygtwCCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e1aPxGuu, 0, m, &cVar_e1aPxGuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u3meVRIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NUpNkzhR, 1, m, &cIf_NUpNkzhR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fG6xuYfT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_yKp4x5iN, m);
}

void Heavy_WSTD_DL3Y::cBinop_VZJmKUjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fG6xuYfT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_cyrlZlhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NUpNkzhR, 0, m, &cIf_NUpNkzhR_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_KZnuopet_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8brvIaxv, 0, m, &cSlice_8brvIaxv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_igkcjFfY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_8brvIaxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QzJy5Pqz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QzJy5Pqz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_OFoAAuRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QzJy5Pqz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_QzJy5Pqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nwGKluU9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Rz1A6I2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_w7FsFrKX_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_2pX77CbU, 0, m, &cIf_2pX77CbU_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_2pX77CbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FCNcsT6H_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_SMZZscix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_W6JAMx8t_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NiGgO1g7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_JgA2eidC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bfg4eiky, HV_BINOP_POW, 0, m, &cBinop_Bfg4eiky_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Bfg4eiky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5QzQk5f0, 0, m, &cIf_5QzQk5f0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qt69iqvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_lwL39JVn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QPLD7Isf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3IzTayPx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RudtuxKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SMZZscix, 0, m, &cIf_SMZZscix_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3IzTayPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SMZZscix, 1, m, &cIf_SMZZscix_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NiGgO1g7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Qt69iqvY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_W6JAMx8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_5QzQk5f0, 0, m, &cIf_5QzQk5f0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lwL39JVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bfg4eiky, HV_BINOP_POW, 1, m, &cBinop_Bfg4eiky_sendMessage);
  cMsg_JgA2eidC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_5QzQk5f0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_r6SS0Hq9, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_w7FsFrKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2pX77CbU, 1, m, &cIf_2pX77CbU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FCNcsT6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aWYsItyI, HV_BINOP_GREATER_THAN, 1, m, &cBinop_aWYsItyI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JCU5I2x4, HV_BINOP_EQ, 1, m, &cBinop_JCU5I2x4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_39u5VCGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_44XgG9uf, HV_BINOP_ADD, 0, m, &cBinop_44XgG9uf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_44XgG9uf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QPLD7Isf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RudtuxKo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aWYsItyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5QzQk5f0, 1, m, &cIf_5QzQk5f0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JCU5I2x4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_On5b8QHj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_On5b8QHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_r6SS0Hq9, m);
}

void Heavy_WSTD_DL3Y::cCast_9WAZrxn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_39u5VCGw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_LqTFjyiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_44XgG9uf, HV_BINOP_ADD, 1, m, &cBinop_44XgG9uf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_aWYsItyI, HV_BINOP_GREATER_THAN, 0, m, &cBinop_aWYsItyI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JCU5I2x4, HV_BINOP_EQ, 0, m, &cBinop_JCU5I2x4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FLOQZYlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Rz1A6I2m, 0, m, &cVar_Rz1A6I2m_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_bb6fFvzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RoVN85Ux_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_a3UwhUoc, 0, m, &cIf_a3UwhUoc_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_a3UwhUoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IAtatUxp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_eSKDtoWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_DyR1z7Xn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NeLE80UM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_pZxSNNni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nvsWvVVq, HV_BINOP_POW, 0, m, &cBinop_nvsWvVVq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nvsWvVVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KYIQXFdl, 0, m, &cIf_KYIQXFdl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PMZcphfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_AlJJWUmA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TkgITXge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_d1MurxPW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Lxv8Dyeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eSKDtoWW, 0, m, &cIf_eSKDtoWW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d1MurxPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eSKDtoWW, 1, m, &cIf_eSKDtoWW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NeLE80UM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_PMZcphfr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DyR1z7Xn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_KYIQXFdl, 0, m, &cIf_KYIQXFdl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AlJJWUmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nvsWvVVq, HV_BINOP_POW, 1, m, &cBinop_nvsWvVVq_sendMessage);
  cMsg_pZxSNNni_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_KYIQXFdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RNuvd0zX_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WDlEyDM1_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_NBQesEL2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_RoVN85Ux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a3UwhUoc, 1, m, &cIf_a3UwhUoc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IAtatUxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qPStWYkH, HV_BINOP_GREATER_THAN, 1, m, &cBinop_qPStWYkH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UpVdTE3l, HV_BINOP_EQ, 1, m, &cBinop_UpVdTE3l_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JjRLCJMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lFxnFYWM, HV_BINOP_ADD, 0, m, &cBinop_lFxnFYWM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lFxnFYWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TkgITXge_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lxv8Dyeo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qPStWYkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KYIQXFdl, 1, m, &cIf_KYIQXFdl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UpVdTE3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hsI4q7IR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_hsI4q7IR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RNuvd0zX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WDlEyDM1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_NBQesEL2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EtY64yPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bb6fFvzH, 0, m, &cVar_bb6fFvzH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Td78vQpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JjRLCJMM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_4qsCwnux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lFxnFYWM, HV_BINOP_ADD, 1, m, &cBinop_lFxnFYWM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qPStWYkH, HV_BINOP_GREATER_THAN, 0, m, &cBinop_qPStWYkH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UpVdTE3l, HV_BINOP_EQ, 0, m, &cBinop_UpVdTE3l_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_B73uDL98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KSfjLr3G_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_aFUUN4rb, 0, m, &cIf_aFUUN4rb_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_aFUUN4rb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Ouc859Kb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_7bXkWRSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_hbZ53U8R_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_G5rxNoUo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_01Jlyey5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qzg7un4d, HV_BINOP_POW, 0, m, &cBinop_Qzg7un4d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qzg7un4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Husmx9Fw, 0, m, &cIf_Husmx9Fw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JZvb8AjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_x6AiTWl5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NWDKXEx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QA1gNYWb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_78zw6g7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7bXkWRSZ, 0, m, &cIf_7bXkWRSZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QA1gNYWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7bXkWRSZ, 1, m, &cIf_7bXkWRSZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_G5rxNoUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_JZvb8AjZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hbZ53U8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Husmx9Fw, 0, m, &cIf_Husmx9Fw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x6AiTWl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qzg7un4d, HV_BINOP_POW, 1, m, &cBinop_Qzg7un4d_sendMessage);
  cMsg_01Jlyey5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_Husmx9Fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_bwd5ZXj7, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_KSfjLr3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aFUUN4rb, 1, m, &cIf_aFUUN4rb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ouc859Kb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c5mJVTe1, HV_BINOP_GREATER_THAN, 1, m, &cBinop_c5mJVTe1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CpYe2XWB, HV_BINOP_EQ, 1, m, &cBinop_CpYe2XWB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_O6Qf0ua3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7PyRzMal, HV_BINOP_ADD, 0, m, &cBinop_7PyRzMal_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7PyRzMal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NWDKXEx6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_78zw6g7p_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c5mJVTe1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Husmx9Fw, 1, m, &cIf_Husmx9Fw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CpYe2XWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AM4HINpf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_AM4HINpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bwd5ZXj7, m);
}

void Heavy_WSTD_DL3Y::cCast_8BpZW3LM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O6Qf0ua3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_VsrY30jT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7PyRzMal, HV_BINOP_ADD, 1, m, &cBinop_7PyRzMal_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_c5mJVTe1, HV_BINOP_GREATER_THAN, 0, m, &cBinop_c5mJVTe1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CpYe2XWB, HV_BINOP_EQ, 0, m, &cBinop_CpYe2XWB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BMkSH7lc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_B73uDL98, 0, m, &cVar_B73uDL98_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_cgeZWFgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_4uGd7y62, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_dM4smFZ3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dHfkF8qh, 0, m, &cSlice_dHfkF8qh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_tBSAnxmd_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_dHfkF8qh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gRzPkWyA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gRzPkWyA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_73Ii4imu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gRzPkWyA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_gRzPkWyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CtLb9Rd0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_tBSAnxmd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yJrfCZP2, 0, m, &cSlice_yJrfCZP2_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KZnuopet_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_yJrfCZP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zxQTAfzN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zxQTAfzN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_8vn2Bogi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zxQTAfzN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_zxQTAfzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qSwnDbdr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_igkcjFfY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DE1N7xmL, 0, m, &cSlice_DE1N7xmL_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cnUKSN50_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_DE1N7xmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_uuSzTJTE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_uuSzTJTE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_o5rak8md_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uuSzTJTE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_uuSzTJTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fFbwT78p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_cnUKSN50_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dq5w1ZlS, 0, m, &cSlice_dq5w1ZlS_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_dq5w1ZlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7txejCmo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7txejCmo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_F7gg1vEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7txejCmo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_7txejCmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mYCQIPa8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_PgK3mQEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kWVUI3At, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zOadcVEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_knp1B6Mm, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_myYyH2Pp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0u8X6y57, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ZEo3Om5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QiGryqOZ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3VfWEBkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WAZh7KMl, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_jiM19fWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8OXAwCh6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_8OXAwCh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4TIJvFCC, HV_BINOP_DIVIDE, 1, m, &cBinop_4TIJvFCC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YYCc7cyg_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_JuOZ1Oks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_W9a3Sn13_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WscCGiQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_JuOZ1Oks_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W9a3Sn13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4TIJvFCC, HV_BINOP_DIVIDE, 0, m, &cBinop_4TIJvFCC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YYCc7cyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WscCGiQt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4TIJvFCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dlhtLeqm, HV_BINOP_MULTIPLY, 1, m, &cBinop_dlhtLeqm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dlhtLeqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_009MyfOg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sIfY9YHC_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_3dCvUf6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iD4WTipu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_1uQvw7cZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LBSlsZ1U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9qJ45IU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_z9ITweCS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z9ITweCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dlhtLeqm, HV_BINOP_MULTIPLY, 0, m, &cBinop_dlhtLeqm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NZ8X5MYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_8I9oE1vq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8I9oE1vq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z4Mo8gYK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QFJSKbQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hnjsuZLN, 1, m, &cVar_hnjsuZLN_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_hnjsuZLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_02EqMtBf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VO9U0jaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WjPOiiA9, HV_BINOP_MULTIPLY, 1, m, &cBinop_WjPOiiA9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YN4fnQrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VO9U0jaY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2leuJNtZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9ObIxPaF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9ObIxPaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lGQKZ1jA, HV_BINOP_MULTIPLY, 1, m, &cBinop_lGQKZ1jA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xXzOifq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AZytIZGF, HV_BINOP_MULTIPLY, 1, m, &cBinop_AZytIZGF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xpQFJPGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xXzOifq3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bpJ0kJvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KsxG9SYV, HV_BINOP_MULTIPLY, 1, m, &cBinop_KsxG9SYV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CmxlalTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_07wMJS0c_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_07wMJS0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tWikztg5, HV_BINOP_MULTIPLY, 1, m, &cBinop_tWikztg5_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_vTt8KSLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0RwwKkcG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_9qJ45IU0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r1yyMe1y_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_7CX1zIBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_NZ8X5MYn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sIfY9YHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_1uQvw7cZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_009MyfOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_3dCvUf6N_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_iD4WTipu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cq5WSo2z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_LBSlsZ1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7cmKEYq8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Uks5yDb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_t85YnDAL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Z4Mo8gYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lPt0s8ew_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lPt0s8ew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ofgzU0JO, HV_BINOP_MULTIPLY, 1, m, &cBinop_ofgzU0JO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ofgzU0JO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2TpeQwG3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2TpeQwG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Uks5yDb6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_02EqMtBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_y9exN15K_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y9exN15K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_whMA2Ab9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yFxDssgD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9IbC4bTV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eivo4ihv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JyXLvUJb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k2tTSPzy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WjPOiiA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PgK3mQEX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lGQKZ1jA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zOadcVEj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AZytIZGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_myYyH2Pp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KsxG9SYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZEo3Om5G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tWikztg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3VfWEBkT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_iano0E0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vTt8KSLM, 0, m, &cVar_vTt8KSLM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_c7q6BiOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7CX1zIBb, 1, m, &cVar_7CX1zIBb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_eivo4ihv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AZytIZGF, HV_BINOP_MULTIPLY, 0, m, &cBinop_AZytIZGF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_whMA2Ab9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_k2tTSPzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WjPOiiA9, HV_BINOP_MULTIPLY, 0, m, &cBinop_WjPOiiA9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9IbC4bTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KsxG9SYV, HV_BINOP_MULTIPLY, 0, m, &cBinop_KsxG9SYV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JyXLvUJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lGQKZ1jA, HV_BINOP_MULTIPLY, 0, m, &cBinop_lGQKZ1jA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yFxDssgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tWikztg5, HV_BINOP_MULTIPLY, 0, m, &cBinop_tWikztg5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_r1yyMe1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hnjsuZLN, 0, m, &cVar_hnjsuZLN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0RwwKkcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7CX1zIBb, 0, m, &cVar_7CX1zIBb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eqcqbN2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tFHfeXVs, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_uzoCI5rB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AHdHCt7F, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_VUrwJPvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o18T6DQj, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_bE5y4Elk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BMz4b187, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2quBOcey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_c1gp6GfQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_c1gp6GfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1ERSQsFq, HV_BINOP_DIVIDE, 1, m, &cBinop_1ERSQsFq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ESGQLptS_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_cQDNQa4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_JI2Ly0EO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xwya4Tbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_cQDNQa4D_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JI2Ly0EO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1ERSQsFq, HV_BINOP_DIVIDE, 0, m, &cBinop_1ERSQsFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ESGQLptS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xwya4Tbc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1ERSQsFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gpf6vW0s, HV_BINOP_MULTIPLY, 1, m, &cBinop_Gpf6vW0s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Gpf6vW0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zX30tZ34_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NRsNrnMV_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_y61niJHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kbVMj9ip_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_lmF8Uyqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V9E4ezmD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_u2eTyl9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_9QXwSXmf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9QXwSXmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gpf6vW0s, HV_BINOP_MULTIPLY, 0, m, &cBinop_Gpf6vW0s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9r64eCeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_hVe1QPoa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hVe1QPoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AlRxFK1V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_m12BaCuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DKmt8Zu1, HV_BINOP_MULTIPLY, 1, m, &cBinop_DKmt8Zu1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_urna0Blg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kqcgLEp9, 1, m, &cVar_kqcgLEp9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BetdS2gC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OD8r4vgK, HV_BINOP_MULTIPLY, 1, m, &cBinop_OD8r4vgK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xuh0IrmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PFDkmlr4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PFDkmlr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y79wc6To, HV_BINOP_MULTIPLY, 1, m, &cBinop_y79wc6To_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_kqcgLEp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AqxRjbcH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_2I9BCIBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aU5UmyCg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_u2eTyl9m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6mT691SH_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_W5hqsqwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_9r64eCeW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NRsNrnMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_lmF8Uyqs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zX30tZ34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_y61niJHa_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_kbVMj9ip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xhS63ChB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_V9E4ezmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hoxivpse_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_KO1xnmnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BfYkTX4c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_AlRxFK1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5ILaGeYS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5ILaGeYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f4Fr2OKf, HV_BINOP_MULTIPLY, 1, m, &cBinop_f4Fr2OKf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_f4Fr2OKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rYs0IU0U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rYs0IU0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KO1xnmnG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_AqxRjbcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TMRDnLNd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TMRDnLNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V0DGSSUP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KUlj4j7W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VaIFKEFf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_apl3zraN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vz5U03nt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eqcqbN2C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DKmt8Zu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uzoCI5rB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OD8r4vgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VUrwJPvZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_y79wc6To_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bE5y4Elk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_0DIuCVHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2I9BCIBI, 0, m, &cVar_2I9BCIBI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QjjwA1Tb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W5hqsqwl, 1, m, &cVar_W5hqsqwl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6mT691SH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kqcgLEp9, 0, m, &cVar_kqcgLEp9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aU5UmyCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W5hqsqwl, 0, m, &cVar_W5hqsqwl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KUlj4j7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OD8r4vgK, HV_BINOP_MULTIPLY, 0, m, &cBinop_OD8r4vgK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_apl3zraN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vz5U03nt, HV_BINOP_MULTIPLY, 0, m, &cBinop_Vz5U03nt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_V0DGSSUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y79wc6To, HV_BINOP_MULTIPLY, 0, m, &cBinop_y79wc6To_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VaIFKEFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DKmt8Zu1, HV_BINOP_MULTIPLY, 0, m, &cBinop_DKmt8Zu1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OPH11ZKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TJ9u0lih, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qjDdU8vN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lFqLiJIY, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_vnimQcoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jq40YfLY, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_T3pt1cJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vwhRcaVJ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_dQsappLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e8kOgwOL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Do5aJ46h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ODC7H1Us_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ODC7H1Us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KQLFixbZ, HV_BINOP_DIVIDE, 1, m, &cBinop_KQLFixbZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RImlIBhv_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_HEu7gYVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_gltBcfv7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DzuXKXaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_HEu7gYVo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gltBcfv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KQLFixbZ, HV_BINOP_DIVIDE, 0, m, &cBinop_KQLFixbZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RImlIBhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DzuXKXaC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KQLFixbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wMRsLuxL, HV_BINOP_MULTIPLY, 1, m, &cBinop_wMRsLuxL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wMRsLuxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bnm1K8Wp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZwxktZ6V_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_4d6o9EqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bBI4SjfR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_Mb7GHk6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ffapl6C0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_iLOn3cke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Ss86QYmF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ss86QYmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wMRsLuxL, HV_BINOP_MULTIPLY, 0, m, &cBinop_wMRsLuxL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_40chuTje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Ezkuo9aL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ezkuo9aL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VIfPBAWC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_O2Lj3rbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r8fCjQ91, HV_BINOP_MULTIPLY, 1, m, &cBinop_r8fCjQ91_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mFZ77Sr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iSTZkWyP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iSTZkWyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_O2Lj3rbl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UdjwFdrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ba74igdo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ba74igdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IlV4tADR, HV_BINOP_MULTIPLY, 1, m, &cBinop_IlV4tADR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4nwHXJvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UvePjrpV, HV_BINOP_MULTIPLY, 1, m, &cBinop_UvePjrpV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aoV1l17g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3ExbIaDg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3ExbIaDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4nwHXJvR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wFfCzxvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QoIniWQA, 1, m, &cVar_QoIniWQA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zUcn5jwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PrbUMSXD, HV_BINOP_MULTIPLY, 1, m, &cBinop_PrbUMSXD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wnRv29TC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8urE1uVn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8urE1uVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ao7Z5BLZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ao7Z5BLZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_QoIniWQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jg9reLiK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_LIZZliT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kWrVDCN8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_iLOn3cke_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aGbL6Sk8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_DLDkfuUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_40chuTje_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZwxktZ6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Mb7GHk6g_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Bnm1K8Wp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_4d6o9EqC_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_bBI4SjfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_p24hq75h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Ffapl6C0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_t0H4BWas_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_6Iy6R39n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bgJ9zFsx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_VIfPBAWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3Ex7OeYT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3Ex7OeYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dVNenUoN, HV_BINOP_MULTIPLY, 1, m, &cBinop_dVNenUoN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dVNenUoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_s9tAyj1g_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_s9tAyj1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6Iy6R39n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Jg9reLiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_BN5CA4oD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BN5CA4oD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4vyGKlQK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EaHiNpdK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GUBDTM4k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LWy4zgQh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YZFHWm3o_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q3PCh5Kn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_r8fCjQ91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OPH11ZKM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IlV4tADR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qjDdU8vN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UvePjrpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vnimQcoy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PrbUMSXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T3pt1cJ0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ao7Z5BLZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dQsappLV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_5o0BuLDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LIZZliT5, 0, m, &cVar_LIZZliT5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_d7U7dEW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DLDkfuUQ, 1, m, &cVar_DLDkfuUQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GUBDTM4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PrbUMSXD, HV_BINOP_MULTIPLY, 0, m, &cBinop_PrbUMSXD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YZFHWm3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IlV4tADR, HV_BINOP_MULTIPLY, 0, m, &cBinop_IlV4tADR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EaHiNpdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ao7Z5BLZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ao7Z5BLZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LWy4zgQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UvePjrpV, HV_BINOP_MULTIPLY, 0, m, &cBinop_UvePjrpV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4vyGKlQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_Q3PCh5Kn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r8fCjQ91, HV_BINOP_MULTIPLY, 0, m, &cBinop_r8fCjQ91_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aGbL6Sk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QoIniWQA, 0, m, &cVar_QoIniWQA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kWrVDCN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DLDkfuUQ, 0, m, &cVar_DLDkfuUQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RNuvd0zX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cgeZWFgL, 1, m, &cIf_cgeZWFgL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mYW5GN3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_4uGd7y62, m);
}

void Heavy_WSTD_DL3Y::cBinop_WDlEyDM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mYW5GN3o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NBQesEL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cgeZWFgL, 0, m, &cIf_cgeZWFgL_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_HyLeMuXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pCni0f4L, HV_BINOP_DIVIDE, 0, m, &cBinop_pCni0f4L_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_2Y7qSF9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ppdR7a82, HV_BINOP_DIVIDE, 1, m, &cBinop_ppdR7a82_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pCni0f4L, HV_BINOP_DIVIDE, 1, m, &cBinop_pCni0f4L_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_lTaKjxQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LW3Eon4H, HV_BINOP_DIVIDE, 0, m, &cBinop_LW3Eon4H_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_cdy9HDWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LW3Eon4H, HV_BINOP_DIVIDE, 1, m, &cBinop_LW3Eon4H_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_s7gu9ed0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HyLeMuXe, 0, m, &cVar_HyLeMuXe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9IImWtG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2Y7qSF9z, 0, m, &cVar_2Y7qSF9z_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xUksGLGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ppdR7a82, HV_BINOP_DIVIDE, 0, m, &cBinop_ppdR7a82_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ppdR7a82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_lTaKjxQA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pCni0f4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_cdy9HDWz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LW3Eon4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_j1giflx1_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_3tlhmyGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_QMnl17EK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pvXK74IA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_A0nvZqob_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_j1giflx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pvXK74IA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_A0nvZqob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_3tlhmyGL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QMnl17EK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E1X19yr9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_QdqnjVzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UIHnwzmk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Zxhom8ia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fq9w3Xwu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_E0yR0UYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C2C9uQCS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_FpZMV20F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZqFmgisd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_2ompYh3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bBMoTiXR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Cu1Xbmzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O7ZVBhbx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_phbtKwej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_87ddLfjQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_QH7HWYr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oorJrUCA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_34lAlugV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wn3aMkVq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_hzFGP4oM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mnJf6WoE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_IdviiyFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SWOvPlZY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_POFNbRDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_husg70Z5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ajIt4LpF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WbzS6g4B, 0, m, &cSlice_WbzS6g4B_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_WbzS6g4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3eIjb4fc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3eIjb4fc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_dk4mW59N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3eIjb4fc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_3eIjb4fc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BLQqcCdf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_QTDisJR7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wg1ShnRF, 0, m, &cSlice_wg1ShnRF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7ymuDO4v_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_wg1ShnRF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gjbYMUDQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gjbYMUDQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_xatP3RCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gjbYMUDQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_gjbYMUDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mDf5IzQx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_KL78YvTt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0dpDVWH3, 0, m, &cSlice_0dpDVWH3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ajIt4LpF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_0dpDVWH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_1MNkQSP1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_1MNkQSP1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_cdRXixPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1MNkQSP1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_1MNkQSP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_g0DOKFfh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LDGgo6lN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Vvg21eQM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vvg21eQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_nIEqNJ1B_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_J8E85zuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LabyhXAi_sendMessage(_c, 0, m);
  cMsg_uqIVeYMu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_hS2vZzg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hQGRvN4s_sendMessage(_c, 0, m);
  cMsg_UMNokA2M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nIEqNJ1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_CuOK28mm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CuOK28mm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WLDH6d2Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZeYHKKmu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZeYHKKmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lQ83mvrx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_WLDH6d2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9DyoEQpW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9DyoEQpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4F9yH9as_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lQ83mvrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8xgeLKtq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8xgeLKtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Lo5zuqRV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4F9yH9as_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_J8E85zuY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Lo5zuqRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_hS2vZzg7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SqliRBuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0QQszCTm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0QQszCTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_0dwZLB1V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0dwZLB1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UEJ4wdUJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UEJ4wdUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tsGjC42C_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0xDEK7OA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0xDEK7OA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wnp1sjJJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_tsGjC42C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_l8YjeBpi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l8YjeBpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NU8r2kUw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wnp1sjJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HQpeJmqr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HQpeJmqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_OtvxG6eo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OtvxG6eo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sUknPlcR_sendMessage(_c, 0, m);
  cMsg_RtrQyAPN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NU8r2kUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lXW0pRcu_sendMessage(_c, 0, m);
  cMsg_nk5oMwy6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UWZjcEvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ocBqn62P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ocBqn62P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QQ36DAzi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_bOglawRX_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_1LGNMZaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_4R0McRq5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0zqzpTKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_89L5eFkH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_89L5eFkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tKUUKoW7, HV_BINOP_DIVIDE, 1, m, &cBinop_tKUUKoW7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QQ36DAzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9qbnPMZK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9qbnPMZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_PiVErwoQ, m);
}

void Heavy_WSTD_DL3Y::cMsg_bSkjPXa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_58kCutqR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_58kCutqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_UWZjcEvN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bOglawRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VWITC6TO, m);
}

void Heavy_WSTD_DL3Y::cBinop_4R0McRq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_UWSZLzjR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UWSZLzjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tKUUKoW7, HV_BINOP_DIVIDE, 0, m, &cBinop_tKUUKoW7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tKUUKoW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bSkjPXa2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_iFcR8XJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_OMLSTiqd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OMLSTiqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CuREhOfD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Oj8BM1kQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_1KrFFXYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_anjPupF2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Fq86IfTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iUhDKyFG_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_iUhDKyFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j61qRklR, HV_BINOP_DIVIDE, 1, m, &cBinop_j61qRklR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CuREhOfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_iLsNEUL5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iLsNEUL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cOU2HYTP, m);
}

void Heavy_WSTD_DL3Y::cMsg_EaDIFO4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cUXxEJDI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cUXxEJDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_iFcR8XJP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Oj8BM1kQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_oI3sGbOq, m);
}

void Heavy_WSTD_DL3Y::cBinop_anjPupF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_cDlUGKME_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cDlUGKME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j61qRklR, HV_BINOP_DIVIDE, 0, m, &cBinop_j61qRklR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_j61qRklR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EaDIFO4y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_vFu3fWZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YVx3IsvZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_YVx3IsvZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_csyeb857_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_h3I1W3EZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_h3I1W3EZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3ukDh0Mx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YVx3IsvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qK6D5lRQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qkDbjV7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YVx3IsvZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_YVx3IsvZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3ukDh0Mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qkDbjV7N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qK6D5lRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Imeh4tTX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Imeh4tTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6ljIv2yW_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_hLI7WdGP, m);
}

void Heavy_WSTD_DL3Y::cBinop_6ljIv2yW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GbaiSpKi, m);
}

void Heavy_WSTD_DL3Y::cVar_vgLyB0Jv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OuGPLPDD, HV_BINOP_MULTIPLY, 0, m, &cBinop_OuGPLPDD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5hwAjNUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QcGROafm_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_QcGROafm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z4oXoxSR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OuGPLPDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_yPpaJMLY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RQdHwxqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OuGPLPDD, HV_BINOP_MULTIPLY, 1, m, &cBinop_OuGPLPDD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Z4oXoxSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RQdHwxqP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yPpaJMLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_cxeqiTyc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cxeqiTyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6Vhj7Ewt_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dNS4hUBP, m);
}

void Heavy_WSTD_DL3Y::cBinop_6Vhj7Ewt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lWEnBNlj, m);
}

void Heavy_WSTD_DL3Y::sEnv_oaWibKmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_whPNuylN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zRLQXaN4_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_nlL1nfYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_CIVl9ovQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_iIzP0khn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_cqMp5Ijc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rG7T6img, HV_BINOP_POW, 0, m, &cBinop_rG7T6img_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rG7T6img_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rXzVdztW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WXIgZ5wk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_JGL1LdHw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_whPNuylN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uvWBN4YW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zRLQXaN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nlL1nfYc, 0, m, &cIf_nlL1nfYc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uvWBN4YW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nlL1nfYc, 1, m, &cIf_nlL1nfYc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iIzP0khn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_WXIgZ5wk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CIVl9ovQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_rXzVdztW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JGL1LdHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rG7T6img, HV_BINOP_POW, 1, m, &cBinop_rG7T6img_sendMessage);
  cMsg_cqMp5Ijc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_n95b7N4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ftQeJuGX, HV_BINOP_MULTIPLY, 0, m, &cBinop_ftQeJuGX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yQiA2qAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Kcze7Xup_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Kcze7Xup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D4xxSbmI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ftQeJuGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Qs7qtQ8v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LIEZqAU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ftQeJuGX, HV_BINOP_MULTIPLY, 1, m, &cBinop_ftQeJuGX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_D4xxSbmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LIEZqAU3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qs7qtQ8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fw83wC1M_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fw83wC1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jlvJSaev_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_suDzppjU, m);
}

void Heavy_WSTD_DL3Y::cBinop_jlvJSaev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_p9M7SlsG, m);
}

void Heavy_WSTD_DL3Y::cMsg_rXzVdztW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_W1js62cC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W1js62cC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_10ybToXQ, m);
}

void Heavy_WSTD_DL3Y::sEnv_4aE44HEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sNT9917f_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7F6aJD4E_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_pp1cY2op_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_gP7eMhC4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_TM7GjUWz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_AEUeRODi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ez9RsvIl, HV_BINOP_POW, 0, m, &cBinop_ez9RsvIl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ez9RsvIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hd16Lkgf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_M4Wktc4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_P4g3ZBHn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7F6aJD4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pp1cY2op, 0, m, &cIf_pp1cY2op_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sNT9917f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1IE4oXpL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1IE4oXpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pp1cY2op, 1, m, &cIf_pp1cY2op_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TM7GjUWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_M4Wktc4M_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gP7eMhC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_Hd16Lkgf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_P4g3ZBHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ez9RsvIl, HV_BINOP_POW, 1, m, &cBinop_ez9RsvIl_sendMessage);
  cMsg_AEUeRODi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_F6IbCUHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zgIYExkM, HV_BINOP_MULTIPLY, 0, m, &cBinop_zgIYExkM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OHfjA9Je_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fAjYKK74_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_fAjYKK74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RF9k9A0K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zgIYExkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_9mHFyiKM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zdSn5JJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zgIYExkM, HV_BINOP_MULTIPLY, 1, m, &cBinop_zgIYExkM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RF9k9A0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zdSn5JJg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9mHFyiKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_nvtaz8H2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nvtaz8H2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_eFjJiE1l_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Rlnd8Glw, m);
}

void Heavy_WSTD_DL3Y::cBinop_eFjJiE1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_78Em2qIu, m);
}

void Heavy_WSTD_DL3Y::cMsg_Hd16Lkgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KRR0Dp01_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KRR0Dp01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_EZLhgpN1, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_7ymuDO4v_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_11deG3Yi, 0, m, &cSlice_11deG3Yi_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KL78YvTt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_11deG3Yi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MqebHiQP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MqebHiQP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_YID1maYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MqebHiQP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_MqebHiQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5EQ5ZztI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_wcoVOaQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oedlEqjN_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_oedlEqjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Xd3GUTV4_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_94cCukWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_94cCukWY, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_99baWNao, 0, m, &cDelay_99baWNao_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_94cCukWY, 0, m, &cDelay_94cCukWY_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_k20G8px1, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_99baWNao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_99baWNao, m);
  cMsg_3j5QO9ny_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_WSiIuZ1R_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_hs2M06RH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_POesxOe1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qh7QmZjh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_R2myzqZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u3JirWvC_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_94cCukWY, 2, m, &cDelay_94cCukWY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ryO8LoWz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qh7QmZjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_R2myzqZT, 0, m, &hTable_R2myzqZT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Xd3GUTV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_POesxOe1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3j5QO9ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_R2myzqZT, 0, m, &hTable_R2myzqZT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ryO8LoWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_94cCukWY, 0, m, &cDelay_94cCukWY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_u3JirWvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_99baWNao, 2, m, &cDelay_99baWNao_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hs2M06RH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_k20G8px1, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_yLqi2VcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1gnGzsH7, HV_BINOP_SUBTRACT, 0, m, &cBinop_1gnGzsH7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3LEqRWey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NDgSoWev_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_NDgSoWev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_JyDLui7V_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_bqVNDKqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vJs2eFxf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_8aEDAqxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8aEDAqxR, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tvc2r84H, 0, m, &cDelay_tvc2r84H_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_nScVQPQn, 0, m, &sTabread_nScVQPQn_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_tvc2r84H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tvc2r84H, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_nScVQPQn, 0, m, &sTabread_nScVQPQn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tvc2r84H, 0, m, &cDelay_tvc2r84H_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_nScVQPQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_eaWFgQaJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_eaWFgQaJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_3z0xfpc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cjh2OyRl, HV_BINOP_MAX, 0, m, &cBinop_cjh2OyRl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JyDLui7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3z0xfpc4, HV_BINOP_MULTIPLY, 0, m, &cBinop_3z0xfpc4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1gnGzsH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JYOspkUW_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_nScVQPQn, 0, m, &sTabread_nScVQPQn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hmfy1qKa_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7M5Ya691_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eaWFgQaJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_eaWFgQaJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tvc2r84H, 2, m, &cDelay_tvc2r84H_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vJs2eFxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7M5Ya691_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JYOspkUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8aEDAqxR, 0, m, &cDelay_8aEDAqxR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tvc2r84H, 0, m, &cDelay_tvc2r84H_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_W5b4u3fQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_cjh2OyRl, HV_BINOP_MAX, 1, m, &cBinop_cjh2OyRl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cjh2OyRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1gnGzsH7, HV_BINOP_SUBTRACT, 1, m, &cBinop_1gnGzsH7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hmfy1qKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8aEDAqxR, 0, m, &cDelay_8aEDAqxR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wGEw6yBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8aEDAqxR, 2, m, &cDelay_8aEDAqxR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eaWFgQaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wGEw6yBs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XySmMt2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bqVNDKqs, 0, m, &cVar_bqVNDKqs_sendMessage);
  cMsg_3LEqRWey_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_yLqi2VcO, 0, m, &cTabhead_yLqi2VcO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wakju3LU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FPxEiXSl_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_FPxEiXSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_68ELOrgm_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_3M9qj4k0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3M9qj4k0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RLEjMWly, 0, m, &cDelay_RLEjMWly_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3M9qj4k0, 0, m, &cDelay_3M9qj4k0_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6Uvf39V7, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_RLEjMWly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RLEjMWly, m);
  cMsg_T15cNZxe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_V5vEuHmw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_6sAug3xk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_sUAtly0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NQinSY5A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_MVN5OxWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CTNEUFRx_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3M9qj4k0, 2, m, &cDelay_3M9qj4k0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GIkK4hav_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NQinSY5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_MVN5OxWD, 0, m, &hTable_MVN5OxWD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_68ELOrgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_sUAtly0Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_T15cNZxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_MVN5OxWD, 0, m, &hTable_MVN5OxWD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GIkK4hav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3M9qj4k0, 0, m, &cDelay_3M9qj4k0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CTNEUFRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_RLEjMWly, 2, m, &cDelay_RLEjMWly_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6sAug3xk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_6Uvf39V7, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_Sv1dHVn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KNPiKHer, HV_BINOP_SUBTRACT, 0, m, &cBinop_KNPiKHer_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6U56ycsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_f0BDYD8x_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_f0BDYD8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Qu6i1eBw_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_cdjOYsEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6hZVQ06L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_3IYGAz9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3IYGAz9X, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VkCWtASq, 0, m, &cDelay_VkCWtASq_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_uLLhEZG3, 0, m, &sTabread_uLLhEZG3_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_VkCWtASq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VkCWtASq, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_uLLhEZG3, 0, m, &sTabread_uLLhEZG3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VkCWtASq, 0, m, &cDelay_VkCWtASq_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_uLLhEZG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_9twMdQVd, HV_BINOP_SUBTRACT, 0, m, &cBinop_9twMdQVd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_1pDXcWFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nOFdmC8o, HV_BINOP_MAX, 0, m, &cBinop_nOFdmC8o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qu6i1eBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1pDXcWFs, HV_BINOP_MULTIPLY, 0, m, &cBinop_1pDXcWFs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KNPiKHer_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QRJLnSWo_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_uLLhEZG3, 0, m, &sTabread_uLLhEZG3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qgn7WmRg_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_QtmyEUlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9twMdQVd, HV_BINOP_SUBTRACT, 1, m, &cBinop_9twMdQVd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VkCWtASq, 2, m, &cDelay_VkCWtASq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6hZVQ06L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QtmyEUlJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QRJLnSWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3IYGAz9X, 0, m, &cDelay_3IYGAz9X_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VkCWtASq, 0, m, &cDelay_VkCWtASq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SuckRT7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_nOFdmC8o, HV_BINOP_MAX, 1, m, &cBinop_nOFdmC8o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nOFdmC8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KNPiKHer, HV_BINOP_SUBTRACT, 1, m, &cBinop_KNPiKHer_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Qgn7WmRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3IYGAz9X, 0, m, &cDelay_3IYGAz9X_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qyhzayKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3IYGAz9X, 2, m, &cDelay_3IYGAz9X_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9twMdQVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qyhzayKN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RPUNYya6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cdjOYsEb, 0, m, &cVar_cdjOYsEb_sendMessage);
  cMsg_6U56ycsY_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Sv1dHVn2, 0, m, &cTabhead_Sv1dHVn2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LabyhXAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pNpGbAU1, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_hQGRvN4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o9Dz2yYV, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UMNokA2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HVHhQz9Q, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_uqIVeYMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1ArEpuaH, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nk5oMwy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fEhizGBK, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_sUknPlcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JZmg7oYm, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_lXW0pRcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4koZv0G8, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_RtrQyAPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a5T0cMIQ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_RJT9bQHW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qb9NTO4R, 0, m, &cSlice_qb9NTO4R_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_qb9NTO4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CiklCCHi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CiklCCHi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_YCPPa911_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CiklCCHi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_CiklCCHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KTgqqOYO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_lGbCqu28_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GHRhSJms, 0, m, &cSlice_GHRhSJms_sendMessage);
      break;
    }
    default: {
      cSwitchcase_yfXEdGtP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_GHRhSJms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CWXTlZ8e_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CWXTlZ8e_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ylhZHTDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CWXTlZ8e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_CWXTlZ8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4CUFSKln_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_wqdmieWC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_22UejtaT, 0, m, &cSlice_22UejtaT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_RJT9bQHW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_22UejtaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SZqm1iTg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SZqm1iTg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_EeAq0RHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SZqm1iTg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_SZqm1iTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0wiig83b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_k6pWHOCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_xMoZMfex_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xMoZMfex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ETK5WUEz_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_gQxQ2Ol7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bmzgT3ye_sendMessage(_c, 0, m);
  cMsg_jwDHZmBj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_fchxnEMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1eK9iSOi_sendMessage(_c, 0, m);
  cMsg_QHO9PtZJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ETK5WUEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jCgA5UGq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jCgA5UGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VNvVJ1as_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7vYKKlcN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7vYKKlcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DmuKI9ae_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_VNvVJ1as_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_kxJQYAVM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kxJQYAVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hgx53vzs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DmuKI9ae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KYvdseZB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KYvdseZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sAv45uJx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hgx53vzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_gQxQ2Ol7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sAv45uJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_fchxnEMi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xLH6Cfw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_uoyIUZev_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uoyIUZev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_qJ0rbaun_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qJ0rbaun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_WY3RnEQq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WY3RnEQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MYzOIs8c_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EnMNmJub_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EnMNmJub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9fGfDmok_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_MYzOIs8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_comH6iaZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_comH6iaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Tj7NodQ5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9fGfDmok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8vDkRztr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8vDkRztr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8i8sftYO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8i8sftYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OVj3PBSX_sendMessage(_c, 0, m);
  cMsg_wN0rVExJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Tj7NodQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GXATZDhe_sendMessage(_c, 0, m);
  cMsg_6dFCPbFP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6KMq4b9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_hwgI7LUd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hwgI7LUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_g1fBvRt3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_INFTfSJ1_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_b46s5Yuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_khBeUypq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_L7FrJdNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eDx9KuY4_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_eDx9KuY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3PF1kap8, HV_BINOP_DIVIDE, 1, m, &cBinop_3PF1kap8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g1fBvRt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oHgHTvQI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oHgHTvQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Z395AaB4, m);
}

void Heavy_WSTD_DL3Y::cMsg_T8YAkdhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_eFEqh1tg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eFEqh1tg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_6KMq4b9S_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_INFTfSJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DRI09thR, m);
}

void Heavy_WSTD_DL3Y::cBinop_khBeUypq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_HiSGPldd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HiSGPldd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3PF1kap8, HV_BINOP_DIVIDE, 0, m, &cBinop_3PF1kap8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3PF1kap8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T8YAkdhl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_xyihbsjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_1x3GKpcN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1x3GKpcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_LDSFBrlM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vjM2fIt8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_1Z9OjhG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_TcbZayNW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5h4gksWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aVFmzgUJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_aVFmzgUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gRUsvGgT, HV_BINOP_DIVIDE, 1, m, &cBinop_gRUsvGgT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LDSFBrlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FFlka4mZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FFlka4mZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3JhCjtfZ, m);
}

void Heavy_WSTD_DL3Y::cMsg_KwZPXB6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ViYNEjJM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ViYNEjJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_xyihbsjj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vjM2fIt8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_g7xs0Tez, m);
}

void Heavy_WSTD_DL3Y::cBinop_TcbZayNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_8QKqsobe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8QKqsobe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gRUsvGgT, HV_BINOP_DIVIDE, 0, m, &cBinop_gRUsvGgT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gRUsvGgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KwZPXB6K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Svqn8Egk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O3IzRepb, HV_BINOP_MULTIPLY, 0, m, &cBinop_O3IzRepb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UXM8BWiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dZBfm3ET_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_dZBfm3ET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Az1IeS0M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_O3IzRepb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pRdqhL7u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_17cTZL2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O3IzRepb, HV_BINOP_MULTIPLY, 1, m, &cBinop_O3IzRepb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Az1IeS0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_17cTZL2g_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pRdqhL7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_NGRGKVdo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NGRGKVdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RC3khg9z_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_oAMUG4M4, m);
}

void Heavy_WSTD_DL3Y::cBinop_RC3khg9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_a10UnPnL, m);
}

void Heavy_WSTD_DL3Y::cVar_sY0VLE3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TvE7QNEo, HV_BINOP_MULTIPLY, 0, m, &cBinop_TvE7QNEo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YrmTL0nr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AgG1Yf9L_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_AgG1Yf9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Wf9s7iy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TvE7QNEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_HrtI5D3J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9UYwqWrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TvE7QNEo, HV_BINOP_MULTIPLY, 1, m, &cBinop_TvE7QNEo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7Wf9s7iy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9UYwqWrI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HrtI5D3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_L2zT6ZSL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L2zT6ZSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_J2cW2HrP_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ssS4xncX, m);
}

void Heavy_WSTD_DL3Y::cBinop_J2cW2HrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_TK8LsR9Y, m);
}

void Heavy_WSTD_DL3Y::sEnv_FcFpgtGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AgOIabfs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B3W0DZ5q_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_XxZZzshE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Z2AgNhZ8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_cpVtqg40_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_lTtTHjMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_20crV7nd, HV_BINOP_POW, 0, m, &cBinop_20crV7nd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_20crV7nd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iIrmPHLe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6xLV9BdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_kFq46VTJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AgOIabfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Uq0mYLJ9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_B3W0DZ5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XxZZzshE, 0, m, &cIf_XxZZzshE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Uq0mYLJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XxZZzshE, 1, m, &cIf_XxZZzshE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cpVtqg40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_6xLV9BdN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Z2AgNhZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_iIrmPHLe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kFq46VTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_20crV7nd, HV_BINOP_POW, 1, m, &cBinop_20crV7nd_sendMessage);
  cMsg_lTtTHjMs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_nEOAieb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IhtztkKD, HV_BINOP_MULTIPLY, 0, m, &cBinop_IhtztkKD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GkPd10z1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_C1gOimmb_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_C1gOimmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hLuHZTP2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IhtztkKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_3fRdz031_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ltOWWtsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IhtztkKD, HV_BINOP_MULTIPLY, 1, m, &cBinop_IhtztkKD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hLuHZTP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ltOWWtsD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3fRdz031_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rsBzvieW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rsBzvieW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_fIrNdNbZ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eRo1Njsy, m);
}

void Heavy_WSTD_DL3Y::cBinop_fIrNdNbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_evXbVldn, m);
}

void Heavy_WSTD_DL3Y::cMsg_iIrmPHLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_igfbUeOm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_igfbUeOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tiXGAA9w, m);
}

void Heavy_WSTD_DL3Y::sEnv_5PJyj5U6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Og7Rk0xr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UGPWyTXB_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_uwfka12b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_O0TTdcqK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_aHRCMQaP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_BehbC6kK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ByfWtqPs, HV_BINOP_POW, 0, m, &cBinop_ByfWtqPs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ByfWtqPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b8zusNFi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_e6kPeY4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_NRQya1dV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UGPWyTXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uwfka12b, 0, m, &cIf_uwfka12b_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Og7Rk0xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ct7Icb0L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ct7Icb0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uwfka12b, 1, m, &cIf_uwfka12b_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aHRCMQaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_e6kPeY4u_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_O0TTdcqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_b8zusNFi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NRQya1dV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ByfWtqPs, HV_BINOP_POW, 1, m, &cBinop_ByfWtqPs_sendMessage);
  cMsg_BehbC6kK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Q0M8aSZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_czS5iKmS, HV_BINOP_MULTIPLY, 0, m, &cBinop_czS5iKmS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KroUUKOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_J3x2Eutb_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_J3x2Eutb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6vfDH10d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_czS5iKmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_grrk9is9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8tYXgZGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_czS5iKmS, HV_BINOP_MULTIPLY, 1, m, &cBinop_czS5iKmS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6vfDH10d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8tYXgZGz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_grrk9is9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_wHD5huzV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wHD5huzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_D9KzHMnT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QlJzKQEs, m);
}

void Heavy_WSTD_DL3Y::cBinop_D9KzHMnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zotlnyDh, m);
}

void Heavy_WSTD_DL3Y::cMsg_b8zusNFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HX1b7Vc0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HX1b7Vc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_BQcCus2N, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_yfXEdGtP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fN4lkOKs, 0, m, &cSlice_fN4lkOKs_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wqdmieWC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_fN4lkOKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Ht6pP2wm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Ht6pP2wm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ouQtAJ3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ht6pP2wm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Ht6pP2wm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_39k99Faq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_1LGs4dJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_msbhuoWZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_msbhuoWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_LuCjjUrc_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_8iFHO9ju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8iFHO9ju, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mebqFCd9, 0, m, &cDelay_mebqFCd9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8iFHO9ju, 0, m, &cDelay_8iFHO9ju_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_RNIJIcwq, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_mebqFCd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mebqFCd9, m);
  cMsg_f3qEkeQe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_uY3yelOP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_merO3O8a_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_Esu1a1PM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0WevspRQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_oRRCkbeO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jUaCbFyo_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_8iFHO9ju, 2, m, &cDelay_8iFHO9ju_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Zys5JcPS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0WevspRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_oRRCkbeO, 0, m, &hTable_oRRCkbeO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LuCjjUrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_Esu1a1PM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f3qEkeQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_oRRCkbeO, 0, m, &hTable_oRRCkbeO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Zys5JcPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8iFHO9ju, 0, m, &cDelay_8iFHO9ju_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jUaCbFyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_mebqFCd9, 2, m, &cDelay_mebqFCd9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_merO3O8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_RNIJIcwq, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_njs6DGCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9jBDlUKf, HV_BINOP_SUBTRACT, 0, m, &cBinop_9jBDlUKf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lOed9y6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RzAT2QWG_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_RzAT2QWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_brIAPmxL_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_gsih3KVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Iycz52rz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_cNMXAuxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cNMXAuxb, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vzZSrqoy, 0, m, &cDelay_vzZSrqoy_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_w1wb83pu, 0, m, &sTabread_w1wb83pu_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_vzZSrqoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vzZSrqoy, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_w1wb83pu, 0, m, &sTabread_w1wb83pu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vzZSrqoy, 0, m, &cDelay_vzZSrqoy_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_w1wb83pu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_GLsEE6HF, HV_BINOP_SUBTRACT, 0, m, &cBinop_GLsEE6HF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_9jUjqXDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U81hpKiu, HV_BINOP_MAX, 0, m, &cBinop_U81hpKiu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_brIAPmxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9jUjqXDS, HV_BINOP_MULTIPLY, 0, m, &cBinop_9jUjqXDS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9jBDlUKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VtPBjANk_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_w1wb83pu, 0, m, &sTabread_w1wb83pu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uv3e1CZ8_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_sYSSANsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GLsEE6HF, HV_BINOP_SUBTRACT, 1, m, &cBinop_GLsEE6HF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vzZSrqoy, 2, m, &cDelay_vzZSrqoy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Iycz52rz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sYSSANsP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VtPBjANk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cNMXAuxb, 0, m, &cDelay_cNMXAuxb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vzZSrqoy, 0, m, &cDelay_vzZSrqoy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eRKD2lUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_U81hpKiu, HV_BINOP_MAX, 1, m, &cBinop_U81hpKiu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U81hpKiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9jBDlUKf, HV_BINOP_SUBTRACT, 1, m, &cBinop_9jBDlUKf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uv3e1CZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cNMXAuxb, 0, m, &cDelay_cNMXAuxb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_whw5CQ3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cNMXAuxb, 2, m, &cDelay_cNMXAuxb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GLsEE6HF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_whw5CQ3y_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hlIyr0tc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gsih3KVF, 0, m, &cVar_gsih3KVF_sendMessage);
  cMsg_lOed9y6Z_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_njs6DGCA, 0, m, &cTabhead_njs6DGCA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XwTYQRx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YQNP0qTI_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_YQNP0qTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ByIE6UbU_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_F0cDWDsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_F0cDWDsR, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_26BWTfH5, 0, m, &cDelay_26BWTfH5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_F0cDWDsR, 0, m, &cDelay_F0cDWDsR_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4Dv0Py1I, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_26BWTfH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_26BWTfH5, m);
  cMsg_rJuyRSce_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_M5Qw0L0q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ygJRON3j_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_qQLOPBwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iZkj7g7j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_xSB6bK9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e3s1o53A_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_F0cDWDsR, 2, m, &cDelay_F0cDWDsR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IFTHLfF6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iZkj7g7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_xSB6bK9e, 0, m, &hTable_xSB6bK9e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ByIE6UbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_qQLOPBwO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rJuyRSce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_xSB6bK9e, 0, m, &hTable_xSB6bK9e_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IFTHLfF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_F0cDWDsR, 0, m, &cDelay_F0cDWDsR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_e3s1o53A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_26BWTfH5, 2, m, &cDelay_26BWTfH5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ygJRON3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4Dv0Py1I, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_RbjVJ54y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_byzmLiAt, HV_BINOP_SUBTRACT, 0, m, &cBinop_byzmLiAt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Kez8gQ3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Zx3bgitb_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Zx3bgitb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cNDVzgWC_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_kuVIzDlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KADSeif5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_nxofu98h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nxofu98h, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LPw2tMeX, 0, m, &cDelay_LPw2tMeX_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Bo9vkCmw, 0, m, &sTabread_Bo9vkCmw_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_LPw2tMeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LPw2tMeX, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Bo9vkCmw, 0, m, &sTabread_Bo9vkCmw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LPw2tMeX, 0, m, &cDelay_LPw2tMeX_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_Bo9vkCmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_IZx2i5Su, HV_BINOP_SUBTRACT, 0, m, &cBinop_IZx2i5Su_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_UwSsbLVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OYluVjm3, HV_BINOP_MAX, 0, m, &cBinop_OYluVjm3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cNDVzgWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UwSsbLVV, HV_BINOP_MULTIPLY, 0, m, &cBinop_UwSsbLVV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_byzmLiAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9AplXUp8_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Bo9vkCmw, 0, m, &sTabread_Bo9vkCmw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0xbTOnmc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_SwaF1lJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IZx2i5Su, HV_BINOP_SUBTRACT, 1, m, &cBinop_IZx2i5Su_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LPw2tMeX, 2, m, &cDelay_LPw2tMeX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KADSeif5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SwaF1lJg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9AplXUp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nxofu98h, 0, m, &cDelay_nxofu98h_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LPw2tMeX, 0, m, &cDelay_LPw2tMeX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pfsvOYvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_OYluVjm3, HV_BINOP_MAX, 1, m, &cBinop_OYluVjm3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OYluVjm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_byzmLiAt, HV_BINOP_SUBTRACT, 1, m, &cBinop_byzmLiAt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0xbTOnmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nxofu98h, 0, m, &cDelay_nxofu98h_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Bq83QokC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nxofu98h, 2, m, &cDelay_nxofu98h_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IZx2i5Su_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Bq83QokC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9tMNLfjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kuVIzDlx, 0, m, &cVar_kuVIzDlx_sendMessage);
  cMsg_Kez8gQ3d_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_RbjVJ54y, 0, m, &cTabhead_RbjVJ54y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bmzgT3ye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kDSOVsqg, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_1eK9iSOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JxiuCwrU, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_QHO9PtZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lPVZE2Vi, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_jwDHZmBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QfzYVHoh, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6dFCPbFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p1YAPTc4, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_OVj3PBSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_y8EwRDFa, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GXATZDhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z5IGU0Mz, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_wN0rVExJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AaYX8chq, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_tuY7UImg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MBY5WCXS, 0, m, &cSlice_MBY5WCXS_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_MBY5WCXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GMVq8LHv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GMVq8LHv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_SllWV9Ve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GMVq8LHv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_GMVq8LHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Jylxf14t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Oclqopkd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FJJTm7s2, 0, m, &cSlice_FJJTm7s2_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WLvAw92E_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_FJJTm7s2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iTyG8tEQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iTyG8tEQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ovezZS1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iTyG8tEQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_iTyG8tEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uzVgDRo0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Z4lzpMiL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QbyN00Qf, 0, m, &cSlice_QbyN00Qf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_tuY7UImg_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_QbyN00Qf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ruo4s3gX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ruo4s3gX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_nnyyOWry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ruo4s3gX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ruo4s3gX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Pg9YN0bO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ffTagSIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DDEfnZgT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DDEfnZgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ZyWwucmG_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_gz9ZGOOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j7qRtvjM_sendMessage(_c, 0, m);
  cMsg_0EF3xDbM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_4Qxgi5wm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tdp4cEUR_sendMessage(_c, 0, m);
  cMsg_UkZdNr6e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZyWwucmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_s2s7TZtq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_s2s7TZtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DMZ8iIy7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WHjekPat_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WHjekPat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qX7p6MXI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_DMZ8iIy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zotfXBpy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zotfXBpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kJW3iSrm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qX7p6MXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WQ0gmQpV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WQ0gmQpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bviE8GkX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kJW3iSrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_gz9ZGOOh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bviE8GkX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_4Qxgi5wm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I5VCVPtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gp4W5rm2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gp4W5rm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_WGnR2BZ9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WGnR2BZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NVhdlWvR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NVhdlWvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3yuwwyUX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fRp1a5t3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fRp1a5t3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pyEPDVo0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_3yuwwyUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MKKrfXuV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MKKrfXuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vbBtChat_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pyEPDVo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_d87Oj98W_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d87Oj98W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_F2c9LoIY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F2c9LoIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NriNEDZe_sendMessage(_c, 0, m);
  cMsg_IDHsiuyD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vbBtChat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zyff74sp_sendMessage(_c, 0, m);
  cMsg_yDIWoyct_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_dgVrd57P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_n4awGjKB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n4awGjKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_V2hZzvdw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DdY2ZYsy_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_oKEGWkLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_6xgi3Dgq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VlOL7vtu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_66N86a0Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_66N86a0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RcTTZBVe, HV_BINOP_DIVIDE, 1, m, &cBinop_RcTTZBVe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V2hZzvdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_emfNcoun_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_emfNcoun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0rf5BjXd, m);
}

void Heavy_WSTD_DL3Y::cMsg_8OahHKz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uEO1FSwA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uEO1FSwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_dgVrd57P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DdY2ZYsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_57agI3uY, m);
}

void Heavy_WSTD_DL3Y::cBinop_6xgi3Dgq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_hdQ1cC6M_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hdQ1cC6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RcTTZBVe, HV_BINOP_DIVIDE, 0, m, &cBinop_RcTTZBVe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RcTTZBVe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8OahHKz7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_u3Bhw2M3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0Y0WaxeF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0Y0WaxeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_OBcP9IoR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_H6dXKLAT_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_v0wvXDMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_ouMqX81g_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cieP2oWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Wv6MAqpZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Wv6MAqpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zu4XGwcD, HV_BINOP_DIVIDE, 1, m, &cBinop_Zu4XGwcD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OBcP9IoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_X4VzkcwF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_X4VzkcwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_sywZ3S7M, m);
}

void Heavy_WSTD_DL3Y::cMsg_vx2U1Fni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_heLTIob8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_heLTIob8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_u3Bhw2M3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_H6dXKLAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9YBWklWT, m);
}

void Heavy_WSTD_DL3Y::cBinop_ouMqX81g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_iFOIYZnZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iFOIYZnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zu4XGwcD, HV_BINOP_DIVIDE, 0, m, &cBinop_Zu4XGwcD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Zu4XGwcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vx2U1Fni_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_aC4wXbIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Umas2s8y, HV_BINOP_MULTIPLY, 0, m, &cBinop_Umas2s8y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UnSye7mo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5r2QaZ18_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_5r2QaZ18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mU72Z5Gq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Umas2s8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZzOZ5YZh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0kz9P0pt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Umas2s8y, HV_BINOP_MULTIPLY, 1, m, &cBinop_Umas2s8y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mU72Z5Gq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0kz9P0pt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZzOZ5YZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_eZdyHHae_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eZdyHHae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_n8sfp3ia_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dMYRclrw, m);
}

void Heavy_WSTD_DL3Y::cBinop_n8sfp3ia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hhgkU99N, m);
}

void Heavy_WSTD_DL3Y::cVar_6gzWtZjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_baJkrYtZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_baJkrYtZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_G2pNrAPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qIgqFkAM_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_qIgqFkAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_doh2Jz5F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_baJkrYtZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_NKlyOK7O_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nagqkKOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_baJkrYtZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_baJkrYtZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_doh2Jz5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_nagqkKOT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NKlyOK7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_klO3V54l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_klO3V54l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Cai1ABUI_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BWaM5VKC, m);
}

void Heavy_WSTD_DL3Y::cBinop_Cai1ABUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_sK1IrKlT, m);
}

void Heavy_WSTD_DL3Y::sEnv_juL7aCDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WuZ0hcmO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vVsn9rE0_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_YkIfry0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_apmyuRlp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_KkEQiH36_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_8GfCwT52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6c9EuX1w, HV_BINOP_POW, 0, m, &cBinop_6c9EuX1w_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6c9EuX1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hNfNdp2k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ORsVRVCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_cFZHz4jO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vVsn9rE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YkIfry0b, 0, m, &cIf_YkIfry0b_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WuZ0hcmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yO5HRREr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yO5HRREr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YkIfry0b, 1, m, &cIf_YkIfry0b_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KkEQiH36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ORsVRVCU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_apmyuRlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_hNfNdp2k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_cFZHz4jO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6c9EuX1w, HV_BINOP_POW, 1, m, &cBinop_6c9EuX1w_sendMessage);
  cMsg_8GfCwT52_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_F9m0rpZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YWr38sL6, HV_BINOP_MULTIPLY, 0, m, &cBinop_YWr38sL6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NaukufRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Gc245lRL_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Gc245lRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OK1W46EL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YWr38sL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_HohhAm9J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uxrLukIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YWr38sL6, HV_BINOP_MULTIPLY, 1, m, &cBinop_YWr38sL6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OK1W46EL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uxrLukIi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HohhAm9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_5Ncc6CCc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5Ncc6CCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_iIRjaJaA_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_FaTgmkQJ, m);
}

void Heavy_WSTD_DL3Y::cBinop_iIRjaJaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HbIulFDV, m);
}

void Heavy_WSTD_DL3Y::cMsg_hNfNdp2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_48AxnkYL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_48AxnkYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Xent26Vk, m);
}

void Heavy_WSTD_DL3Y::sEnv_DkRqr3xX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dg8kjag4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0kmI58wg_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_M1L36Djn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_lzUm10lH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_uy1vMiy4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_FgMm2fmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GYlvlBCy, HV_BINOP_POW, 0, m, &cBinop_GYlvlBCy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GYlvlBCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3yl75u4g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Gcnv23CY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_EaavI6eh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0kmI58wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M1L36Djn, 0, m, &cIf_M1L36Djn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Dg8kjag4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YWpWX3hm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YWpWX3hm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M1L36Djn, 1, m, &cIf_M1L36Djn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uy1vMiy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Gcnv23CY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lzUm10lH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_3yl75u4g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_EaavI6eh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GYlvlBCy, HV_BINOP_POW, 1, m, &cBinop_GYlvlBCy_sendMessage);
  cMsg_FgMm2fmB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_tftUM1ZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vBlO2N9J, HV_BINOP_MULTIPLY, 0, m, &cBinop_vBlO2N9J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zbuskKDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GDbOOmAs_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_GDbOOmAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OfNrn9pw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vBlO2N9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ltTflUbG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8Y2UHiTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vBlO2N9J, HV_BINOP_MULTIPLY, 1, m, &cBinop_vBlO2N9J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OfNrn9pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8Y2UHiTB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ltTflUbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_uPUAsU5A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uPUAsU5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1ZXd4Txq_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_nq66zUOl, m);
}

void Heavy_WSTD_DL3Y::cBinop_1ZXd4Txq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Qbg2q7g1, m);
}

void Heavy_WSTD_DL3Y::cMsg_3yl75u4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Y91lYGdX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Y91lYGdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GOBbsio9, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_WLvAw92E_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gZDt0Lxn, 0, m, &cSlice_gZDt0Lxn_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Z4lzpMiL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_gZDt0Lxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7PnoMM7T_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7PnoMM7T_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_zW7szdpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7PnoMM7T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_7PnoMM7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3AJScKrz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_0qvPIbQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uK0u2Ghr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_uK0u2Ghr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_LqQudvg3_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_mvTUFyS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mvTUFyS4, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_04vf9zV7, 0, m, &cDelay_04vf9zV7_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mvTUFyS4, 0, m, &cDelay_mvTUFyS4_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NfuZeXac, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_04vf9zV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_04vf9zV7, m);
  cMsg_Xgc7NX4q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Mn8bWwXu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_vPETJW9z_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_gxwsAWNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nFiKV50b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_kM4T4Iep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8LLccb5F_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mvTUFyS4, 2, m, &cDelay_mvTUFyS4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jgq0mGxi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nFiKV50b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_kM4T4Iep, 0, m, &hTable_kM4T4Iep_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LqQudvg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_gxwsAWNL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Xgc7NX4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_kM4T4Iep, 0, m, &hTable_kM4T4Iep_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jgq0mGxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mvTUFyS4, 0, m, &cDelay_mvTUFyS4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8LLccb5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_04vf9zV7, 2, m, &cDelay_04vf9zV7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vPETJW9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_NfuZeXac, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_1mIa3Y8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3hlGoZ85, HV_BINOP_SUBTRACT, 0, m, &cBinop_3hlGoZ85_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7W4tUEyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_i4veyZoS_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_i4veyZoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_JAytCFDc_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_2W8wEOre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EhuFSFDd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_NmPSMefJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NmPSMefJ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pU6uA26j, 0, m, &cDelay_pU6uA26j_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_LeONmoMc, 0, m, &sTabread_LeONmoMc_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_pU6uA26j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pU6uA26j, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_LeONmoMc, 0, m, &sTabread_LeONmoMc_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pU6uA26j, 0, m, &cDelay_pU6uA26j_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_LeONmoMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_lbTnbFu7, HV_BINOP_SUBTRACT, 0, m, &cBinop_lbTnbFu7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_i9XznoTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DK3YmITt, HV_BINOP_MAX, 0, m, &cBinop_DK3YmITt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JAytCFDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i9XznoTl, HV_BINOP_MULTIPLY, 0, m, &cBinop_i9XznoTl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3hlGoZ85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_isZq2qYs_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_LeONmoMc, 0, m, &sTabread_LeONmoMc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qcUKcWB9_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_L0M2TM1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lbTnbFu7, HV_BINOP_SUBTRACT, 1, m, &cBinop_lbTnbFu7_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pU6uA26j, 2, m, &cDelay_pU6uA26j_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EhuFSFDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_L0M2TM1O_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_isZq2qYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NmPSMefJ, 0, m, &cDelay_NmPSMefJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pU6uA26j, 0, m, &cDelay_pU6uA26j_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oRDvot0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_DK3YmITt, HV_BINOP_MAX, 1, m, &cBinop_DK3YmITt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DK3YmITt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3hlGoZ85, HV_BINOP_SUBTRACT, 1, m, &cBinop_3hlGoZ85_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qcUKcWB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NmPSMefJ, 0, m, &cDelay_NmPSMefJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8lnnX65f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NmPSMefJ, 2, m, &cDelay_NmPSMefJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lbTnbFu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8lnnX65f_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NaTxFWox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2W8wEOre, 0, m, &cVar_2W8wEOre_sendMessage);
  cMsg_7W4tUEyD_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_1mIa3Y8v, 0, m, &cTabhead_1mIa3Y8v_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_G2AYFwWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MdhJTm7j_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_MdhJTm7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GHXifAnv_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_vB4pS315_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vB4pS315, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_skXfkBkk, 0, m, &cDelay_skXfkBkk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vB4pS315, 0, m, &cDelay_vB4pS315_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_i9jtsZhG, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_skXfkBkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_skXfkBkk, m);
  cMsg_8VyH1lSg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_cVr2F5sI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_vBkpX9z4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_xQVPZmKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_plQFKaf8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_He6s9FFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UdRYizRZ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vB4pS315, 2, m, &cDelay_vB4pS315_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CkGewFRK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_plQFKaf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_He6s9FFS, 0, m, &hTable_He6s9FFS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GHXifAnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_xQVPZmKG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8VyH1lSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_He6s9FFS, 0, m, &hTable_He6s9FFS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CkGewFRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vB4pS315, 0, m, &cDelay_vB4pS315_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UdRYizRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_skXfkBkk, 2, m, &cDelay_skXfkBkk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vBkpX9z4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_i9jtsZhG, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_5Pd8p5ZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9RFLRsAr, HV_BINOP_SUBTRACT, 0, m, &cBinop_9RFLRsAr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RJ1wFEpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kA2U9iib_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_kA2U9iib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_S12HGP60_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_llwV4VcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xwzqiUj7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_UpJi5cso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UpJi5cso, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_W4GGN6XC, 0, m, &cDelay_W4GGN6XC_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gGnZJsO8, 0, m, &sTabread_gGnZJsO8_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_W4GGN6XC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_W4GGN6XC, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gGnZJsO8, 0, m, &sTabread_gGnZJsO8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_W4GGN6XC, 0, m, &cDelay_W4GGN6XC_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_gGnZJsO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_9hhVHGbC, HV_BINOP_SUBTRACT, 0, m, &cBinop_9hhVHGbC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_BnYvU5H1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pmh7Pgyu, HV_BINOP_MAX, 0, m, &cBinop_pmh7Pgyu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_S12HGP60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BnYvU5H1, HV_BINOP_MULTIPLY, 0, m, &cBinop_BnYvU5H1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9RFLRsAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1sVFdTiy_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_gGnZJsO8, 0, m, &sTabread_gGnZJsO8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_izO11EDQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_JrnGImIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9hhVHGbC, HV_BINOP_SUBTRACT, 1, m, &cBinop_9hhVHGbC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_W4GGN6XC, 2, m, &cDelay_W4GGN6XC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xwzqiUj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JrnGImIv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1sVFdTiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UpJi5cso, 0, m, &cDelay_UpJi5cso_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_W4GGN6XC, 0, m, &cDelay_W4GGN6XC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_s8l9ULI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_pmh7Pgyu, HV_BINOP_MAX, 1, m, &cBinop_pmh7Pgyu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pmh7Pgyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9RFLRsAr, HV_BINOP_SUBTRACT, 1, m, &cBinop_9RFLRsAr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_izO11EDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UpJi5cso, 0, m, &cDelay_UpJi5cso_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cTtzlqGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UpJi5cso, 2, m, &cDelay_UpJi5cso_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9hhVHGbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_cTtzlqGm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_A8q7UqAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_llwV4VcY, 0, m, &cVar_llwV4VcY_sendMessage);
  cMsg_RJ1wFEpQ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5Pd8p5ZE, 0, m, &cTabhead_5Pd8p5ZE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_j7qRtvjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GtPd1Ei0, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tdp4cEUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CsWu34YR, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UkZdNr6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BH6kGA86, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_0EF3xDbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iJTp0Xx5, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_yDIWoyct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Zm9kYflH, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_NriNEDZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0qYUVJxN, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Zyff74sp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5S8dJErk, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_IDHsiuyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_y5OOJdrK, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_jFrr6FEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UwpkkSTG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NsgHvIRt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VEb8qOWm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UwpkkSTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jFrr6FEN, 1, m, &cVar_jFrr6FEN_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_5YsdFUXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Zxhom8ia, 0, m, &cVar_Zxhom8ia_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_egspMgUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Zxhom8ia, 0, m, &cVar_Zxhom8ia_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ZViYPiP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_egspMgUD, 0, m, &cIf_egspMgUD_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_oeMlSTCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5YsdFUXb, 0, m, &cIf_5YsdFUXb_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_zYYqHFC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EZi48uZR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bhVctkr6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CWN9k740_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EZi48uZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zYYqHFC6, 1, m, &cVar_zYYqHFC6_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_h6bc3OLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Cu1Xbmzw, 0, m, &cVar_Cu1Xbmzw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_3fm2wcME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Cu1Xbmzw, 0, m, &cVar_Cu1Xbmzw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_QLkj3W6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3fm2wcME, 0, m, &cIf_3fm2wcME_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Da6UDJos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h6bc3OLW, 0, m, &cIf_h6bc3OLW_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xPHm1fXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_C65wonud_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m90dEZr9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5Knks75A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_C65wonud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xPHm1fXR, 1, m, &cVar_xPHm1fXR_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_1xzRAbNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_hzFGP4oM, 0, m, &cVar_hzFGP4oM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_ecEnxNYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_hzFGP4oM, 0, m, &cVar_hzFGP4oM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_I30FAzAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ecEnxNYM, 0, m, &cIf_ecEnxNYM_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_iLSPKDMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1xzRAbNo, 0, m, &cIf_1xzRAbNo_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Iy1z3EXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C8xhqsvn, HV_BINOP_DIVIDE, 0, m, &cBinop_C8xhqsvn_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_VAccfhpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A07Pbfcg, HV_BINOP_MULTIPLY, 1, m, &cBinop_A07Pbfcg_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_63ZGfvj1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jgYsmRpo, 0, m, &cSlice_jgYsmRpo_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uIYwQHzv, 0, m, &cSlice_uIYwQHzv_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_63Zqq8Gk_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p80PSgos_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_jgYsmRpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_9XIJ2A1B, 0, m, &cVar_9XIJ2A1B_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_9XIJ2A1B, 0, m, &cVar_9XIJ2A1B_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_uIYwQHzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_FSJ0TERl, HV_BINOP_NEQ, 1, m, &cBinop_FSJ0TERl_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_9XIJ2A1B, 1, m, &cVar_9XIJ2A1B_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_FSJ0TERl, HV_BINOP_NEQ, 1, m, &cBinop_FSJ0TERl_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_9XIJ2A1B, 1, m, &cVar_9XIJ2A1B_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_9XIJ2A1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_442ELhcu_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Ha837b36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2k7PJMyu_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hEdQCqiS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_hEdQCqiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9XIJ2A1B, 0, m, &cVar_9XIJ2A1B_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2k7PJMyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FSJ0TERl, HV_BINOP_NEQ, 1, m, &cBinop_FSJ0TERl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FSJ0TERl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ha837b36, 1, m, &cIf_Ha837b36_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_p80PSgos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ha837b36, 0, m, &cIf_Ha837b36_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_63Zqq8Gk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FSJ0TERl, HV_BINOP_NEQ, 0, m, &cBinop_FSJ0TERl_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_8moU870I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GI1fwjWk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xsjRzJwv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_BHDYrtVj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b0iTFtOa_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AXIgzyMn_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KzxDETSE_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zEUgY2aX_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dqRcZZrZ_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e5HIEzVV_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZLY926CR_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DJeeINC3_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HMCMMx0j_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m9kfdFgB_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u0vZQPWS_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J9ypwais_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uzctvB51_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_b0iTFtOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7EEQs9ef_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_AXIgzyMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GdSyHOMk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_KzxDETSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NrdxBxaL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_zEUgY2aX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_opwqoJx7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_dqRcZZrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IcHR1zO4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_e5HIEzVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ab4h8Ctg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ZLY926CR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uFh7hZOf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_DJeeINC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JF77r3JO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_HMCMMx0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fcB4fnSx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_m9kfdFgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Zke3nVP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_u0vZQPWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tX3yP8O6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_J9ypwais_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TJW9DH07_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_uzctvB51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UWiVfLRB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_C8xhqsvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A07Pbfcg, HV_BINOP_MULTIPLY, 0, m, &cBinop_A07Pbfcg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_A07Pbfcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_63ZGfvj1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_xsjRzJwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Iy1z3EXG, 0, m, &cVar_Iy1z3EXG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VAccfhpB, 0, m, &cVar_VAccfhpB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GI1fwjWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C8xhqsvn, HV_BINOP_DIVIDE, 1, m, &cBinop_C8xhqsvn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4AzDxbJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VAccfhpB, 0, m, &cVar_VAccfhpB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_eUoQYcFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Iy1z3EXG, 0, m, &cVar_Iy1z3EXG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7EEQs9ef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4AzDxbJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUoQYcFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GdSyHOMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4AzDxbJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUoQYcFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NrdxBxaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4AzDxbJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUoQYcFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_opwqoJx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4AzDxbJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUoQYcFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IcHR1zO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4AzDxbJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUoQYcFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ab4h8Ctg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4AzDxbJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUoQYcFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uFh7hZOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4AzDxbJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUoQYcFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JF77r3JO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4AzDxbJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUoQYcFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fcB4fnSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4AzDxbJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUoQYcFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5Zke3nVP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4AzDxbJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUoQYcFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tX3yP8O6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4AzDxbJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUoQYcFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TJW9DH07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4AzDxbJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUoQYcFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UWiVfLRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4AzDxbJZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eUoQYcFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_4mp9q3pr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lKbqvUti, HV_BINOP_DIVIDE, 0, m, &cBinop_lKbqvUti_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_XqJH8Vyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BjmrDDFD, HV_BINOP_MULTIPLY, 1, m, &cBinop_BjmrDDFD_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_any52sM3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_I8M3TgMR, 0, m, &cSlice_I8M3TgMR_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FHTmA47I, 0, m, &cSlice_FHTmA47I_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q3fy2lza_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WtQ0oT11_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_I8M3TgMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_33NPZ0kB, 0, m, &cVar_33NPZ0kB_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_33NPZ0kB, 0, m, &cVar_33NPZ0kB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_FHTmA47I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_JlayS1vu, HV_BINOP_NEQ, 1, m, &cBinop_JlayS1vu_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_33NPZ0kB, 1, m, &cVar_33NPZ0kB_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_JlayS1vu, HV_BINOP_NEQ, 1, m, &cBinop_JlayS1vu_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_33NPZ0kB, 1, m, &cVar_33NPZ0kB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_33NPZ0kB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_jMsJuvFQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_yaTB7AJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MW1VdXus_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qGIW0nBb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_qGIW0nBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_33NPZ0kB, 0, m, &cVar_33NPZ0kB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MW1VdXus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JlayS1vu, HV_BINOP_NEQ, 1, m, &cBinop_JlayS1vu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JlayS1vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yaTB7AJz, 1, m, &cIf_yaTB7AJz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WtQ0oT11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yaTB7AJz, 0, m, &cIf_yaTB7AJz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_q3fy2lza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JlayS1vu, HV_BINOP_NEQ, 0, m, &cBinop_JlayS1vu_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_E5TC2wnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y6PN5fUl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GJujmWNr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_R1emSzKH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w1VpepU0_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CeShrups_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cvCVDwce_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kqFargsA_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q0i0rsed_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_csNvdgyM_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ssPinFWK_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6PnlBtmt_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d7NeyWlD_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mtrgFpL5_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i0VdRoyI_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qf047tO5_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rdnA9AmW_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_w1VpepU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W1nMDX6C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_CeShrups_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5ZrCsEmB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_cvCVDwce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H7WYLU5O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_kqFargsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eeq7BwGK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Q0i0rsed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_novzbsKN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_csNvdgyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OM2IoWp7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ssPinFWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QzOrSFFP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_6PnlBtmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_arn0DpE9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_d7NeyWlD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sgBBbhFw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_mtrgFpL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NSJegwWH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_i0VdRoyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nqAzlZnx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Qf047tO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T4R9CDSD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_rdnA9AmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B1JcegXd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lKbqvUti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BjmrDDFD, HV_BINOP_MULTIPLY, 0, m, &cBinop_BjmrDDFD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BjmrDDFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_any52sM3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_GJujmWNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4mp9q3pr, 0, m, &cVar_4mp9q3pr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XqJH8Vyy, 0, m, &cVar_XqJH8Vyy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_y6PN5fUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lKbqvUti, HV_BINOP_DIVIDE, 1, m, &cBinop_lKbqvUti_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GKrdldKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4mp9q3pr, 0, m, &cVar_4mp9q3pr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_g1kPXOrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XqJH8Vyy, 0, m, &cVar_XqJH8Vyy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_W1nMDX6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1kPXOrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKrdldKF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5ZrCsEmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1kPXOrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKrdldKF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_H7WYLU5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1kPXOrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKrdldKF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eeq7BwGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1kPXOrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKrdldKF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_novzbsKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1kPXOrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKrdldKF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OM2IoWp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1kPXOrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKrdldKF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QzOrSFFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1kPXOrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKrdldKF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_arn0DpE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1kPXOrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKrdldKF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sgBBbhFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1kPXOrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKrdldKF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NSJegwWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1kPXOrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKrdldKF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nqAzlZnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1kPXOrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKrdldKF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_T4R9CDSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1kPXOrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKrdldKF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_B1JcegXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1kPXOrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKrdldKF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ufzRF05v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qZK2MOwd, HV_BINOP_DIVIDE, 0, m, &cBinop_qZK2MOwd_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_AC6a8xZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ghdJl2JB, HV_BINOP_MULTIPLY, 1, m, &cBinop_ghdJl2JB_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_SgjFGkbF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cSCxawB4, 0, m, &cSlice_cSCxawB4_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ld9YEEz9, 0, m, &cSlice_ld9YEEz9_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KtkklKNX_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d0nStjzL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_cSCxawB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_lLSO4AFQ, 0, m, &cVar_lLSO4AFQ_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_lLSO4AFQ, 0, m, &cVar_lLSO4AFQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_ld9YEEz9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_PMtv59fc, HV_BINOP_NEQ, 1, m, &cBinop_PMtv59fc_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_lLSO4AFQ, 1, m, &cVar_lLSO4AFQ_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_PMtv59fc, HV_BINOP_NEQ, 1, m, &cBinop_PMtv59fc_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_lLSO4AFQ, 1, m, &cVar_lLSO4AFQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_lLSO4AFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_7uybTalp_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_6vSAnowe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VwsEEY9J_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f7yUnutb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_f7yUnutb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lLSO4AFQ, 0, m, &cVar_lLSO4AFQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VwsEEY9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PMtv59fc, HV_BINOP_NEQ, 1, m, &cBinop_PMtv59fc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PMtv59fc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6vSAnowe, 1, m, &cIf_6vSAnowe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_d0nStjzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6vSAnowe, 0, m, &cIf_6vSAnowe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KtkklKNX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PMtv59fc, HV_BINOP_NEQ, 0, m, &cBinop_PMtv59fc_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_rPEiZk2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6cpdBFie_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LcKFPJnk_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_6jxDphHA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sXX9mJNY_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E6SV5tHo_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VvTcjR6T_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C8K4q5Wb_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bi7Uo0yF_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p0C8DqNi_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2YWimtGg_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o5qJBbD2_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5voPbJBb_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7ZoFovPH_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5WYjl70O_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RYMOhIJ2_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZFu2aTmH_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_sXX9mJNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SkmE5Vgn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_E6SV5tHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5YSIeqLv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_VvTcjR6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HZ71AjkO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_C8K4q5Wb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jcARU1Py_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Bi7Uo0yF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UP5mQubv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_p0C8DqNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qO7ekudi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_2YWimtGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tww2aYzg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_o5qJBbD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hJvMBTB8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_5voPbJBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QP8KYpZ1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_7ZoFovPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zApoYoih_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_5WYjl70O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K7uV9cLY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_RYMOhIJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lYEdnEz7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ZFu2aTmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tFNygN3I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qZK2MOwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ghdJl2JB, HV_BINOP_MULTIPLY, 0, m, &cBinop_ghdJl2JB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ghdJl2JB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SgjFGkbF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_6cpdBFie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qZK2MOwd, HV_BINOP_DIVIDE, 1, m, &cBinop_qZK2MOwd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LcKFPJnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ufzRF05v, 0, m, &cVar_ufzRF05v_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AC6a8xZ2, 0, m, &cVar_AC6a8xZ2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hvbXyvci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ufzRF05v, 0, m, &cVar_ufzRF05v_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0T7WMRkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AC6a8xZ2, 0, m, &cVar_AC6a8xZ2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SkmE5Vgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0T7WMRkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvbXyvci_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5YSIeqLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0T7WMRkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvbXyvci_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HZ71AjkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0T7WMRkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvbXyvci_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jcARU1Py_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0T7WMRkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvbXyvci_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UP5mQubv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0T7WMRkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvbXyvci_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qO7ekudi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0T7WMRkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvbXyvci_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tww2aYzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0T7WMRkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvbXyvci_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hJvMBTB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0T7WMRkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvbXyvci_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QP8KYpZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0T7WMRkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvbXyvci_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zApoYoih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0T7WMRkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvbXyvci_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_K7uV9cLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0T7WMRkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvbXyvci_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lYEdnEz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0T7WMRkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvbXyvci_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tFNygN3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0T7WMRkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hvbXyvci_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RSU5xwLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XZmagjIq_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_dM4smFZ3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_xHr2hw93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XZmagjIq_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_dM4smFZ3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_DEnPPMGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XZmagjIq_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_dM4smFZ3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ypCOsAgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XZmagjIq_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_dM4smFZ3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_E1X19yr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XZmagjIq_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_dM4smFZ3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_VscpZ89q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_YDcjCjga, 0, m, &cVar_YDcjCjga_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ka1VkIwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_RjW0suIO, 0, m, &cVar_RjW0suIO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_G0uDoKEJ, 0, m, &cVar_G0uDoKEJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_y8smK4aw, 0, m, &cVar_y8smK4aw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZqFmgisd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QTDisJR7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UIHnwzmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QTDisJR7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_8LhAn3VU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FpZMV20F, 0, m, &cVar_FpZMV20F_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_93LKW1Lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QdqnjVzh, 0, m, &cVar_QdqnjVzh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NPIgveaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E0yR0UYD, 0, m, &cVar_E0yR0UYD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Fq9w3Xwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QTDisJR7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_C2C9uQCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_QTDisJR7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_oorJrUCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_lGbCqu28_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_bBMoTiXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_lGbCqu28_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_LVsc7EZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QH7HWYr7, 0, m, &cVar_QH7HWYr7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aqcT2WUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2ompYh3R, 0, m, &cVar_2ompYh3R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CoYUZBOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_phbtKwej, 0, m, &cVar_phbtKwej_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_O7ZVBhbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_lGbCqu28_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_87ddLfjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_lGbCqu28_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_husg70Z5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Oclqopkd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Wn3aMkVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Oclqopkd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_uXwbdmf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_POFNbRDe, 0, m, &cVar_POFNbRDe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_54TIuvwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_34lAlugV, 0, m, &cVar_34lAlugV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GNdaLfgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IdviiyFi, 0, m, &cVar_IdviiyFi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mnJf6WoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Oclqopkd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_SWOvPlZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Oclqopkd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_442ELhcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oeMlSTCh, 0, m, &cVar_oeMlSTCh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VEb8qOWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o9MHJaoQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xf36sj5H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NsgHvIRt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C0JeslFV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pqye2r8j_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_C0JeslFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_egspMgUD, 1, m, &cIf_egspMgUD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pqye2r8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZViYPiP6, 0, m, &cVar_ZViYPiP6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xf36sj5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oeMlSTCh, 0, m, &cVar_oeMlSTCh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_o9MHJaoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5YsdFUXb, 1, m, &cIf_5YsdFUXb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jMsJuvFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Da6UDJos, 0, m, &cVar_Da6UDJos_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CWN9k740_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sXz1dmsX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yzbPKEKZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bhVctkr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kpLhXgNQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sLddZTmz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kpLhXgNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3fm2wcME, 1, m, &cIf_3fm2wcME_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sLddZTmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QLkj3W6a, 0, m, &cVar_QLkj3W6a_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sXz1dmsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h6bc3OLW, 1, m, &cIf_h6bc3OLW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yzbPKEKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Da6UDJos, 0, m, &cVar_Da6UDJos_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7uybTalp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iLSPKDMl, 0, m, &cVar_iLSPKDMl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5Knks75A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qrBaMjSO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gbIuD9Xr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_m90dEZr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Av5HsZIC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VLtrxc9Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VLtrxc9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I30FAzAH, 0, m, &cVar_I30FAzAH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Av5HsZIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ecEnxNYM, 1, m, &cIf_ecEnxNYM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qrBaMjSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1xzRAbNo, 1, m, &cIf_1xzRAbNo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gbIuD9Xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iLSPKDMl, 0, m, &cVar_iLSPKDMl_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_MPW1zVT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RjW0suIO, 0, m, &cVar_RjW0suIO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_d4L9g3F0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_G0uDoKEJ, 0, m, &cVar_G0uDoKEJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_YiAFrJDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y8smK4aw, 0, m, &cVar_y8smK4aw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_NlZYKUy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4U2CEBc0, 0, m, &cVar_4U2CEBc0_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_GCkY0jog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dfOJWqA8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dyWFGHI0_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_S2A7ZvXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3Foh1n2A_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z416TJEN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SKOOuj3x_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_kZknpgBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o3RGIfOt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CyKH0Z5J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QiyTeJn8_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_gogYyWze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_apLrbgSc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dkk5H4ax_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BJw0DmIb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_itNsLg7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6SvejpzL_sendMessage(_c, 0, m);
  cMsg_lW69kk1K_sendMessage(_c, 0, m);
  cMsg_gtDTVefu_sendMessage(_c, 0, m);
  cMsg_jiM19fWc_sendMessage(_c, 0, m);
  cMsg_2quBOcey_sendMessage(_c, 0, m);
  cMsg_Do5aJ46h_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WcFmTRzH, 0, m, &cVar_WcFmTRzH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4U2CEBc0, 0, m, &cVar_4U2CEBc0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JDDkkKAM, 0, m, &cVar_JDDkkKAM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vTt8KSLM, 0, m, &cVar_vTt8KSLM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2I9BCIBI, 0, m, &cVar_2I9BCIBI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LIZZliT5, 0, m, &cVar_LIZZliT5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8gw4BkbR, 0, m, &cVar_8gw4BkbR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5LmQIXF1, 0, m, &cVar_5LmQIXF1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_e6gbqMd2, 0, m, &cVar_e6gbqMd2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Jqq0QgVR, 0, m, &cVar_Jqq0QgVR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_A3NKbzaV, 0, m, &cVar_A3NKbzaV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_thM8cOWw, 0, m, &cVar_thM8cOWw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_t1NnIfOE, 0, m, &cVar_t1NnIfOE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oRY7RWtK, 0, m, &cVar_oRY7RWtK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OFoAAuRR, 0, m, &cVar_OFoAAuRR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Rz1A6I2m, 0, m, &cVar_Rz1A6I2m_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bb6fFvzH, 0, m, &cVar_bb6fFvzH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_B73uDL98, 0, m, &cVar_B73uDL98_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_73Ii4imu, 0, m, &cVar_73Ii4imu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8vn2Bogi, 0, m, &cVar_8vn2Bogi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_o5rak8md, 0, m, &cVar_o5rak8md_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_F7gg1vEQ, 0, m, &cVar_F7gg1vEQ_sendMessage);
  cMsg_yQiA2qAo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_n95b7N4O, 0, m, &cVar_n95b7N4O_sendMessage);
  cMsg_OHfjA9Je_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_F6IbCUHM, 0, m, &cVar_F6IbCUHM_sendMessage);
  cMsg_GkPd10z1_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nEOAieb9, 0, m, &cVar_nEOAieb9_sendMessage);
  cMsg_KroUUKOv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Q0M8aSZe, 0, m, &cVar_Q0M8aSZe_sendMessage);
  cMsg_NaukufRi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_F9m0rpZg, 0, m, &cVar_F9m0rpZg_sendMessage);
  cMsg_zbuskKDi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tftUM1ZI, 0, m, &cVar_tftUM1ZI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dk4mW59N, 0, m, &cVar_dk4mW59N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xatP3RCq, 0, m, &cVar_xatP3RCq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cdRXixPY, 0, m, &cVar_cdRXixPY_sendMessage);
  cMsg_0zqzpTKU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1LGNMZaK, 0, m, &cVar_1LGNMZaK_sendMessage);
  cMsg_Fq86IfTd_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1KrFFXYf, 0, m, &cVar_1KrFFXYf_sendMessage);
  cMsg_csyeb857_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vFu3fWZ9, 0, m, &cVar_vFu3fWZ9_sendMessage);
  cMsg_5hwAjNUw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vgLyB0Jv, 0, m, &cVar_vgLyB0Jv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YID1maYG, 0, m, &cVar_YID1maYG_sendMessage);
  cMsg_wcoVOaQO_sendMessage(_c, 0, m);
  cMsg_wakju3LU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YCPPa911, 0, m, &cVar_YCPPa911_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ylhZHTDa, 0, m, &cVar_ylhZHTDa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EeAq0RHQ, 0, m, &cVar_EeAq0RHQ_sendMessage);
  cMsg_L7FrJdNY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_b46s5Yuc, 0, m, &cVar_b46s5Yuc_sendMessage);
  cMsg_5h4gksWQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1Z9OjhG3, 0, m, &cVar_1Z9OjhG3_sendMessage);
  cMsg_UXM8BWiW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Svqn8Egk, 0, m, &cVar_Svqn8Egk_sendMessage);
  cMsg_YrmTL0nr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sY0VLE3M, 0, m, &cVar_sY0VLE3M_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ouQtAJ3I, 0, m, &cVar_ouQtAJ3I_sendMessage);
  cMsg_1LGs4dJp_sendMessage(_c, 0, m);
  cMsg_XwTYQRx7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_SllWV9Ve, 0, m, &cVar_SllWV9Ve_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ovezZS1h, 0, m, &cVar_ovezZS1h_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nnyyOWry, 0, m, &cVar_nnyyOWry_sendMessage);
  cMsg_VlOL7vtu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_oKEGWkLK, 0, m, &cVar_oKEGWkLK_sendMessage);
  cMsg_cieP2oWK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_v0wvXDMn, 0, m, &cVar_v0wvXDMn_sendMessage);
  cMsg_UnSye7mo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_aC4wXbIZ, 0, m, &cVar_aC4wXbIZ_sendMessage);
  cMsg_G2pNrAPN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6gzWtZjj, 0, m, &cVar_6gzWtZjj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zW7szdpD, 0, m, &cVar_zW7szdpD_sendMessage);
  cMsg_0qvPIbQJ_sendMessage(_c, 0, m);
  cMsg_G2AYFwWB_sendMessage(_c, 0, m);
  cMsg_Ka1VkIwz_sendMessage(_c, 0, m);
  cMsg_VscpZ89q_sendMessage(_c, 0, m);
  cMsg_W5b4u3fQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bqVNDKqs, 0, m, &cVar_bqVNDKqs_sendMessage);
  cMsg_3LEqRWey_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_yLqi2VcO, 0, m, &cTabhead_yLqi2VcO_sendMessage);
  cMsg_SuckRT7U_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cdjOYsEb, 0, m, &cVar_cdjOYsEb_sendMessage);
  cMsg_6U56ycsY_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Sv1dHVn2, 0, m, &cTabhead_Sv1dHVn2_sendMessage);
  cMsg_eRKD2lUW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gsih3KVF, 0, m, &cVar_gsih3KVF_sendMessage);
  cMsg_lOed9y6Z_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_njs6DGCA, 0, m, &cTabhead_njs6DGCA_sendMessage);
  cMsg_pfsvOYvk_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_kuVIzDlx, 0, m, &cVar_kuVIzDlx_sendMessage);
  cMsg_Kez8gQ3d_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_RbjVJ54y, 0, m, &cTabhead_RbjVJ54y_sendMessage);
  cMsg_oRDvot0O_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2W8wEOre, 0, m, &cVar_2W8wEOre_sendMessage);
  cMsg_7W4tUEyD_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_1mIa3Y8v, 0, m, &cTabhead_1mIa3Y8v_sendMessage);
  cMsg_s8l9ULI6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_llwV4VcY, 0, m, &cVar_llwV4VcY_sendMessage);
  cMsg_RJ1wFEpQ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5Pd8p5ZE, 0, m, &cTabhead_5Pd8p5ZE_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_zOqlYOFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pr4piZYu, HV_BINOP_MULTIPLY, 0, m, &cBinop_pr4piZYu_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_kxm5lUrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lh8x0JPr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9mJBKhX7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Ojp3O0GF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_BZea6vNH_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ACVPVQ4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_UpAX0zk2_sendMessage);
  cMsg_J8SbWwLv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_mY2w3VIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JGQOakqJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_JGQOakqJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Yd23yfli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_f77dKKl8_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_lk9jW1hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E74i8dXw, HV_BINOP_MULTIPLY, 1, m, &cBinop_E74i8dXw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_dk7RAWAK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_d2ig83re_sendMessage);
  cMsg_K1Ekb9O3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_uBbzPtti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5L3LLGTN, HV_BINOP_MULTIPLY, 0, m, &cBinop_5L3LLGTN_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_AwfKSAnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z0D30M4v_sendMessage(_c, 0, m);
  cMsg_erwO3C3r_sendMessage(_c, 0, m);
  cMsg_CxDXypju_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_AorZr3GR_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_pWBoqbiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_W52BGA5d_sendMessage);
  cMsg_dzNXn0qn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_nwGKluU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2I9BCIBI, 0, m, &cVar_2I9BCIBI_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_mYCQIPa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QjjwA1Tb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0DIuCVHS_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_CtLb9Rd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FLOQZYlm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LqTFjyiQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9WAZrxn3_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_fFbwT78p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BMkSH7lc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VsrY30jT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8BpZW3LM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_qSwnDbdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EtY64yPt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4qsCwnux_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Td78vQpb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_cq5WSo2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ofgzU0JO, HV_BINOP_MULTIPLY, 0, m, &cBinop_ofgzU0JO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_7cmKEYq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YN4fnQrG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_2leuJNtZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xpQFJPGu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_bpJ0kJvm_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_t85YnDAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QFJSKbQy_sendMessage);
  cMsg_CmxlalTd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_xhS63ChB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f4Fr2OKf, HV_BINOP_MULTIPLY, 0, m, &cBinop_f4Fr2OKf_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_hoxivpse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_BetdS2gC_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_BfYkTX4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vz5U03nt, HV_BINOP_MULTIPLY, 1, m, &cBinop_Vz5U03nt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_m12BaCuK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_urna0Blg_sendMessage);
  cMsg_xuh0IrmX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_p24hq75h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dVNenUoN, HV_BINOP_MULTIPLY, 0, m, &cBinop_dVNenUoN_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_t0H4BWas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mFZ77Sr2_sendMessage(_c, 0, m);
  cMsg_UdjwFdrG_sendMessage(_c, 0, m);
  cMsg_aoV1l17g_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_zUcn5jwn_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_bgJ9zFsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wFfCzxvv_sendMessage);
  cMsg_wnRv29TC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_Uk23L6Ki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YDcjCjga, 0, m, &cVar_YDcjCjga_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_pRULAY6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_8LhAn3VU_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_tb3HZcz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_93LKW1Lr_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_bQVr6Unj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_NPIgveaY_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_tD9XkNaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_LVsc7EZ5_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_w65Wp7K1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_aqcT2WUB_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_isqyCBK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_uXwbdmf1_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_JJlHctv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_54TIuvwh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Ts7B3nuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_GNdaLfgp_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_gV1c3zEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_CoYUZBOE_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_g0DOKFfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3z0xfpc4, HV_BINOP_MULTIPLY, 1, m, &cBinop_3z0xfpc4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XySmMt2S_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1pDXcWFs, HV_BINOP_MULTIPLY, 1, m, &cBinop_1pDXcWFs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RPUNYya6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5EQ5ZztI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_e6yP8oMb, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7RyaHMyZ, m);
}

void Heavy_WSTD_DL3Y::cReceive_BLQqcCdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LDGgo6lN_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_mDf5IzQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_SqliRBuN_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_0wiig83b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9jUjqXDS, HV_BINOP_MULTIPLY, 1, m, &cBinop_9jUjqXDS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hlIyr0tc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UwSsbLVV, HV_BINOP_MULTIPLY, 1, m, &cBinop_UwSsbLVV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9tMNLfjE_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_39k99Faq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Bbk0irTW, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LuraM9ou, m);
}

void Heavy_WSTD_DL3Y::cReceive_KTgqqOYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_k6pWHOCv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4CUFSKln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_xLH6Cfw4_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Pg9YN0bO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i9XznoTl, HV_BINOP_MULTIPLY, 1, m, &cBinop_i9XznoTl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NaTxFWox_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BnYvU5H1, HV_BINOP_MULTIPLY, 1, m, &cBinop_BnYvU5H1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A8q7UqAB_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_3AJScKrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hUu53iti, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_hUI6Sexy, m);
}

void Heavy_WSTD_DL3Y::cReceive_Jylxf14t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ffTagSIk_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_uzVgDRo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_I5VCVPtq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_TGZtYfLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZViYPiP6, 0, m, &cVar_ZViYPiP6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_7RTFSgc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jFrr6FEN, 0, m, &cVar_jFrr6FEN_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ify9ZVpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zYYqHFC6, 0, m, &cVar_zYYqHFC6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4n0dFnzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QLkj3W6a, 0, m, &cVar_QLkj3W6a_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_NHG71IaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I30FAzAH, 0, m, &cVar_I30FAzAH_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4xtqEXeM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xPHm1fXR, 0, m, &cVar_xPHm1fXR_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_m3BlYXAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8moU870I, 0, m, &cVar_8moU870I_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E5TC2wnS, 0, m, &cVar_E5TC2wnS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rPEiZk2H, 0, m, &cVar_rPEiZk2H_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_PaGJ05I9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_R1emSzKH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_YZM4OsHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BHDYrtVj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_JUrNpTTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6jxDphHA_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_fiG6y534, VOf(Bf0));
    __hv_line_f(&sLine_VeXpze6x, VOf(Bf1));
    __hv_line_f(&sLine_TneaQYOq, VOf(Bf2));
    __hv_line_f(&sLine_uEJZMqII, VOf(Bf3));
    __hv_line_f(&sLine_1iDVnS2g, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_XS0XcdT2, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_51mKTE7M, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_tY2hs6cy, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_o63Ff4rH, VOf(Bf1));
    __hv_line_f(&sLine_0bMiTH4r, VOf(Bf0));
    __hv_line_f(&sLine_QqDNPqmM, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_S8QGwJDU, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_yKp4x5iN, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_L9L6MGll, VOf(Bf5));
    __hv_line_f(&sLine_4MIpeaae, VOf(Bf1));
    __hv_line_f(&sLine_0Tt9SfHv, VOf(Bf2));
    __hv_line_f(&sLine_ieujRx1x, VOf(Bf4));
    __hv_line_f(&sLine_bdGJMOx3, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_KU5b9IXy, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_XKEKwLNW, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_kWVUI3At, VOf(Bf6));
    __hv_line_f(&sLine_knp1B6Mm, VOf(Bf2));
    __hv_line_f(&sLine_0u8X6y57, VOf(Bf1));
    __hv_line_f(&sLine_QiGryqOZ, VOf(Bf5));
    __hv_line_f(&sLine_WAZh7KMl, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_lBNKBqYC, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_r6SS0Hq9, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_tFHfeXVs, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_AHdHCt7F, VOf(Bf2));
    __hv_line_f(&sLine_o18T6DQj, VOf(Bf6));
    __hv_line_f(&sLine_BMz4b187, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_TB2Tq8cg, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_4uGd7y62, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_TJ9u0lih, VOf(Bf8));
    __hv_line_f(&sLine_lFqLiJIY, VOf(Bf2));
    __hv_line_f(&sLine_jq40YfLY, VOf(Bf1));
    __hv_line_f(&sLine_vwhRcaVJ, VOf(Bf7));
    __hv_line_f(&sLine_e8kOgwOL, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_05B3FoOo, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_bwd5ZXj7, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_o9Dz2yYV, VOf(Bf9));
    __hv_tabread_f(&sTabread_nScVQPQn, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_pNpGbAU1, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_HVHhQz9Q, VOf(Bf9));
    __hv_tabread_f(&sTabread_uLLhEZG3, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_1ArEpuaH, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_NPfHHC5z, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_VWITC6TO, VOf(Bf3));
    __hv_rpole_f(&sRPole_2Mar3zLy, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_t7V2TcWb, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_PiVErwoQ, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_k20G8px1, VIf(Bf3));
    __hv_varread_f(&sVarf_FZH55G9l, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_oI3sGbOq, VOf(Bf5));
    __hv_rpole_f(&sRPole_bHkv0CvB, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_dEYxticl, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_cOU2HYTP, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_6Uvf39V7, VIf(Bf5));
    __hv_varread_f(&sVarf_e6yP8oMb, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_JZmg7oYm, VOf(Bf1));
    __hv_varread_f(&sVarf_7RyaHMyZ, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_fEhizGBK, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_10ybToXQ, VOf(Bf1));
    __hv_varread_f(&sVarf_suDzppjU, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_p9M7SlsG, VOf(Bf1));
    __hv_rpole_f(&sRPole_Hu85Om2N, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_oaWibKmX, VIf(Bf8), &sEnv_oaWibKmX_sendMessage);
    __hv_varread_f(&sVarf_hLI7WdGP, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_GbaiSpKi, VOf(Bf1));
    __hv_rpole_f(&sRPole_vRIlVije, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_NPfHHC5z, VIf(Bf1));
    __hv_line_f(&sLine_a5T0cMIQ, VOf(Bf1));
    __hv_line_f(&sLine_4koZv0G8, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_EZLhgpN1, VOf(Bf1));
    __hv_varread_f(&sVarf_Rlnd8Glw, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_78Em2qIu, VOf(Bf1));
    __hv_rpole_f(&sRPole_q5JBPriZ, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_4aE44HEO, VIf(Bf8), &sEnv_4aE44HEO_sendMessage);
    __hv_varread_f(&sVarf_dNS4hUBP, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_lWEnBNlj, VOf(Bf1));
    __hv_rpole_f(&sRPole_keNIYp3d, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_FZH55G9l, VIf(Bf1));
    __hv_varwrite_f(&sVarf_RoE4Cp4Z, VIf(Bf2));
    __hv_varread_f(&sVarf_eElseLt1, VOf(Bf2));
    __hv_varread_f(&sVarf_JQsEUnrf, VOf(Bf1));
    __hv_line_f(&sLine_JxiuCwrU, VOf(Bf8));
    __hv_tabread_f(&sTabread_w1wb83pu, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_kDSOVsqg, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_lPVZE2Vi, VOf(Bf8));
    __hv_tabread_f(&sTabread_Bo9vkCmw, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_QfzYVHoh, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_ysubGMOm, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_DRI09thR, VOf(Bf2));
    __hv_rpole_f(&sRPole_L7WpME91, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_5pNwaHjF, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Z395AaB4, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_RNIJIcwq, VIf(Bf2));
    __hv_varread_f(&sVarf_62APFNfR, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_g7xs0Tez, VOf(Bf1));
    __hv_rpole_f(&sRPole_E5kuV6EJ, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_mME5u3Er, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_3JhCjtfZ, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_4Dv0Py1I, VIf(Bf1));
    __hv_varread_f(&sVarf_Bbk0irTW, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_y8EwRDFa, VOf(Bf3));
    __hv_varread_f(&sVarf_LuraM9ou, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_p1YAPTc4, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_tiXGAA9w, VOf(Bf3));
    __hv_varread_f(&sVarf_eRo1Njsy, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_evXbVldn, VOf(Bf3));
    __hv_rpole_f(&sRPole_DDQlKfNe, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_FcFpgtGw, VIf(Bf9), &sEnv_FcFpgtGw_sendMessage);
    __hv_varread_f(&sVarf_oAMUG4M4, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_a10UnPnL, VOf(Bf3));
    __hv_rpole_f(&sRPole_3XujMGD0, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_ysubGMOm, VIf(Bf3));
    __hv_line_f(&sLine_AaYX8chq, VOf(Bf3));
    __hv_line_f(&sLine_z5IGU0Mz, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_BQcCus2N, VOf(Bf3));
    __hv_varread_f(&sVarf_QlJzKQEs, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_zotlnyDh, VOf(Bf3));
    __hv_rpole_f(&sRPole_IAoRAWuU, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_5PJyj5U6, VIf(Bf9), &sEnv_5PJyj5U6_sendMessage);
    __hv_varread_f(&sVarf_ssS4xncX, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_TK8LsR9Y, VOf(Bf3));
    __hv_rpole_f(&sRPole_wH7rsJHc, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_62APFNfR, VIf(Bf3));
    __hv_varwrite_f(&sVarf_e1rmFGbQ, VIf(Bf5));
    __hv_varread_f(&sVarf_jyeBxbBW, VOf(Bf5));
    __hv_varread_f(&sVarf_EzaPhrWD, VOf(Bf3));
    __hv_line_f(&sLine_CsWu34YR, VOf(Bf9));
    __hv_tabread_f(&sTabread_LeONmoMc, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_GtPd1Ei0, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_BH6kGA86, VOf(Bf9));
    __hv_tabread_f(&sTabread_gGnZJsO8, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_iJTp0Xx5, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_o6RKprAI, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_57agI3uY, VOf(Bf5));
    __hv_rpole_f(&sRPole_XlzwbeIP, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_l4XI1Fmf, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_0rf5BjXd, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_NfuZeXac, VIf(Bf5));
    __hv_varread_f(&sVarf_OhKUwzvs, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_9YBWklWT, VOf(Bf3));
    __hv_rpole_f(&sRPole_yiRWdndy, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_Hcb8OVwu, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_sywZ3S7M, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_i9jtsZhG, VIf(Bf3));
    __hv_varread_f(&sVarf_hUu53iti, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_0qYUVJxN, VOf(Bf2));
    __hv_varread_f(&sVarf_hUI6Sexy, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_Zm9kYflH, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Xent26Vk, VOf(Bf2));
    __hv_varread_f(&sVarf_FaTgmkQJ, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_HbIulFDV, VOf(Bf2));
    __hv_rpole_f(&sRPole_Pbg0Kjnx, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_juL7aCDs, VIf(Bf8), &sEnv_juL7aCDs_sendMessage);
    __hv_varread_f(&sVarf_dMYRclrw, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_hhgkU99N, VOf(Bf2));
    __hv_rpole_f(&sRPole_JBfpVrPp, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_o6RKprAI, VIf(Bf2));
    __hv_line_f(&sLine_y5OOJdrK, VOf(Bf2));
    __hv_line_f(&sLine_5S8dJErk, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_GOBbsio9, VOf(Bf2));
    __hv_varread_f(&sVarf_nq66zUOl, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_Qbg2q7g1, VOf(Bf2));
    __hv_rpole_f(&sRPole_61dG7IOa, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_DkRqr3xX, VIf(Bf8), &sEnv_DkRqr3xX_sendMessage);
    __hv_varread_f(&sVarf_BWaM5VKC, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_sK1IrKlT, VOf(Bf2));
    __hv_rpole_f(&sRPole_jzFpBvFF, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_OhKUwzvs, VIf(Bf2));
    __hv_varwrite_f(&sVarf_qUT5pV1v, VIf(Bf1));
    __hv_varwrite_f(&sVarf_HibrmJ6G, VIf(Bf10));
    __hv_varwrite_f(&sVarf_18PdKuYo, VIf(Bf11));
    __hv_varwrite_f(&sVarf_XLQK7Nbd, VIf(Bf12));
    __hv_varwrite_f(&sVarf_eElseLt1, VIf(Bf0));
    __hv_varwrite_f(&sVarf_JQsEUnrf, VIf(Bf6));
    __hv_varwrite_f(&sVarf_jyeBxbBW, VIf(Bf4));
    __hv_varwrite_f(&sVarf_EzaPhrWD, VIf(Bf7));
    __hv_varread_f(&sVarf_HibrmJ6G, VOf(Bf7));
    __hv_varread_f(&sVarf_18PdKuYo, VOf(Bf4));
    __hv_varread_f(&sVarf_XLQK7Nbd, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_RoE4Cp4Z, VOf(Bf6));
    __hv_varread_f(&sVarf_e1rmFGbQ, VOf(Bf7));
    __hv_varread_f(&sVarf_qUT5pV1v, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
